(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    129090,       2899]
NotebookOptionsPosition[    120441,       2774]
NotebookOutlinePosition[    120955,       2794]
CellTagsIndexPosition[    120912,       2791]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"The", " ", "Mantel", " ", "test"}], ",", 
    RowBox[{"named", " ", "after", " ", "Nathan", " ", "Mantel"}], ",", 
    RowBox[{
     RowBox[{
     "is", " ", "a", " ", "statistical", " ", "test", " ", "of", " ", "the", 
      " ", "correlation", " ", "between", " ", "two", " ", 
      RowBox[{"matrices", ".", "The"}], " ", "matrices", " ", "must", " ", 
      "be", " ", "of", " ", "the", " ", "same", " ", "rank"}], ";", 
     RowBox[{"in", " ", "most", " ", "applications"}]}], ",", 
    RowBox[{
    "they", " ", "are", " ", "matrices", " ", "of", " ", "interrelations", 
     " ", "between", " ", "the", " ", "same", " ", "vectors", " ", "of", " ", 
     RowBox[{
     "objects", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "This"}], 
     " ", "function", " ", "performs", " ", "a", " ", "Mantel", " ", "Test", 
     " ", "on", " ", "two", " ", 
     RowBox[{"matrices", ".", "It"}], " ", "returns", " ", "the", " ", "test",
      " ", "statistics", " ", "with", " ", "helpful", " ", 
     RowBox[{"labels", ".", "The"}], " ", "function", " ", "incorporates", 
     " ", "the", " ", "recommendations", " ", "of", " ", "Manly"}], ",", 
    "1986", ",", 
    RowBox[{"Res", ".", "Populat", ".", "Ecol", "."}], ",", 
    RowBox[{"28", ":", 
     RowBox[{"201", "-", 
      RowBox[{"281.", " ", "Usage"}]}], ":", 
     RowBox[{
      RowBox[{"Mantel", "[", 
       RowBox[{"matrix1", ",", "matrix2", ",", "n"}], "]"}], " ", "where", 
      " ", "matrix1", " ", "and", " ", "matrix2", " ", "are", " ", "the", " ",
       "two", " ", "symmetric", " ", "matrices", " ", "whose", " ", "Mantel", 
      " ", "correlation", " ", "is", " ", "to", " ", "be", " ", "calculated", 
      " ", "and", " ", "n", " ", "is", " ", "the", " ", "number", " ", "of", 
      " ", "randomizations", " ", "to", " ", "be", " ", "performed", " ", 
      "to", " ", "compute", " ", "the", " ", "test", " ", 
      RowBox[{"statistics", ".", "\[IndentingNewLine]", "Cite"}], " ", 
      RowBox[{"as", ":", "Polly"}]}]}], ",", 
    RowBox[{
     RowBox[{"P", ".", "D", ".", "2016."}], " ", "Geometric", " ", 
     "morphometrics", " ", "for", " ", 
     RowBox[{"Mathematica", ".", "Version"}], " ", 
     RowBox[{"12.0", ".", "Department"}], " ", "of", " ", "Geological", " ", 
     "Sciences"}], ",", 
    RowBox[{"Indiana", " ", 
     RowBox[{"University", ":", "Bloomington"}]}], ",", 
    RowBox[{"Indiana", "."}]}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Mantel", "[", 
    RowBox[{"matrix1_", ",", "matrix2_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "M1", ",", "M2", ",", "i", ",", "j", ",", "z", ",", "znull", ",", "R1", 
       ",", "R2", ",", "rz", ",", "p"}], "}"}], ",", 
     RowBox[{
      RowBox[{"M1", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"matrix1", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"i", "+", "1"}], ",", 
              RowBox[{"Length", "[", "matrix1", "]"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"matrix1", "-", "1"}], "]"}]}], "}"}]}], "]"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"M1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", 
            RowBox[{"Mean", "[", "M1", "]"}]}], ")"}], "/", 
          RowBox[{"StandardDeviation", "[", "M1", "]"}]}], "&"}], "/@", 
        "M1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"M2", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"matrix2", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"i", "+", "1"}], ",", 
              RowBox[{"Length", "[", "matrix2", "]"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"matrix2", "-", "1"}], "]"}]}], "}"}]}], "]"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"M2", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", 
            RowBox[{"Mean", "[", "M2", "]"}]}], ")"}], "/", 
          RowBox[{"StandardDeviation", "[", "M2", "]"}]}], "&"}], "/@", 
        "M2"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"z", "=", 
       RowBox[{
        RowBox[{"Plus", "@@", 
         RowBox[{"(", 
          RowBox[{"M1", "*", "M2"}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "M1", "]"}], "-", "1"}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"znull", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"R1", "=", 
           RowBox[{"RandomSample", "[", "M1", "]"}]}], ";", 
          RowBox[{"R2", "=", 
           RowBox[{"RandomSample", "[", "M2", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rz", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Plus", "@@", 
              RowBox[{"(", 
               RowBox[{"R1", "*", "R2"}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Length", "[", "R1", "]"}], "-", "1"}], ")"}]}]}]}], 
         ",", 
         RowBox[{"{", "n", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"znull", ",", 
            RowBox[{
             RowBox[{"#", ">", "z"}], "&"}]}], "]"}], "]"}], "/", "n"}], "//",
         "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"{", 
        RowBox[{"z", ",", "p"}], "}"}], "]"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.665135996818096*^9, 3.665135996822098*^9}, {
  3.665136278374973*^9, 3.6651362826406355`*^9}, {3.665136352503788*^9, 
  3.6651363531062145`*^9}},ExpressionUUID->"27519406-215c-4ab1-ab13-\
f3a12ddf6376"],

Cell["\<\
Load data under the form : country name, correlation (ef, em), vector of \
weights for females, then for males
Everything is stored in a big matrix tab0
nd is the number of countries\
\>", "Text",
 CellChangeTimes->{{3.657377007742153*^9, 3.657377108589137*^9}, 
   3.6573777462300005`*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"695de352-d3dc-42e2-b833-6607390127ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "\[Lambda]_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "\[Lambda]"}], " ", 
      RowBox[{"Abs", "[", 
       RowBox[{"x", "-", "2"}], "]"}]}], "]"}], 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "\[Lambda]"}], " ", 
      RowBox[{"Abs", "[", 
       RowBox[{"x", "+", "2"}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.662099749712675*^9, 3.662099775660449*^9}, {
  3.6620999708340216`*^9, 3.6620999791466117`*^9}, {3.6621003638845377`*^9, 
  3.6621003660564375`*^9}, {3.6629815486389723`*^9, 
  3.662981551471982*^9}},ExpressionUUID->"c23f70e5-31fa-4c1f-ac0c-\
fd204b44de1c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\<C:/Users/ddlc/Documents/Dropbox/01. Research/DINKS \
international/computing assortativeness\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tab0", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<input.txt\>\"", ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nd", "=", 
   RowBox[{"Length", "[", "tab0", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.63144448095856*^9, 3.631444487193158*^9}, {
   3.6314445198036966`*^9, 3.6314445304915805`*^9}, {3.6326587132484713`*^9, 
   3.632658714792015*^9}, {3.6373991785334463`*^9, 3.637399187877581*^9}, {
   3.639828943114188*^9, 3.639828948574198*^9}, {3.6420871285077567`*^9, 
   3.642087134429742*^9}, {3.6531383422501135`*^9, 3.653138342814526*^9}, {
   3.6533823217441497`*^9, 3.653382336144744*^9}, {3.657373331308548*^9, 
   3.657373356906211*^9}, 3.6573760236313915`*^9, {3.741325047202462*^9, 
   3.741325057063897*^9}, {3.7413288257421436`*^9, 
   3.741328827275799*^9}},ExpressionUUID->"9fe64fb9-2759-4216-a8d1-\
e76e5405e485"],

Cell["\<\
this table contains : name, correlation (ef, em), rank correlation, 19 shares \
female educ, 19 shares male educ\
\>", "Text",
 CellChangeTimes->{{3.6650487144914417`*^9, 
  3.6650487640506897`*^9}},ExpressionUUID->"24efd72f-fec2-4275-8baf-\
be2da8329aa5"],

Cell["\<\
The following procedure computes the weights p and q given the w and a value \
of lambda\
\>", "Text",
 CellChangeTimes->{{3.6573775232146397`*^9, 3.657377632245211*^9}, 
   3.6573777604577875`*^9, {3.6580421376759634`*^9, 3.658042148678512*^9}, {
   3.6598609473735447`*^9, 3.6598609786123514`*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"a4c4084c-c93b-4605-98e2-599b0e235a07"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pq", "[", 
   RowBox[{"lambda_", ",", "vec_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "n", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", "19"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"wm", "[", "i", "]"}], "=", 
         RowBox[{"vec", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "3"}], "]"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"wf", "[", "i", "]"}], "=", 
         RowBox[{"vec", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "3", "+", "n"}], "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mat", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], 
           RowBox[{"q", "[", "j", "]"}]}], ")"}], " ", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"i", "-", "j"}], ",", "\[Lambda]"}], "]"}], 
         RowBox[{"wf", "[", "i", "]"}], " ", 
         RowBox[{"wm", "[", "j", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}]}], "]"}], "-", 
           RowBox[{"wm", "[", "j", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "2", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}]}], "]"}], "-", 
           RowBox[{"wf", "[", "i", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"var", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"p", "[", "i", "]"}], ",", 
            RowBox[{"9", "/", 
             RowBox[{"Sqrt", "[", "i", "]"}]}], ",", "0", ",", "5000"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "2", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"q", "[", "j", "]"}], ",", " ", 
            RowBox[{
             RowBox[{"Sqrt", "[", "j", "]"}], "/", "3"}], ",", "0", ",", 
            "5000"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "\[Rule]", "6"}], "}"}], ",", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{"sys", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], "\[Rule]", "6"}], ",", 
             RowBox[{"\[Lambda]", "\[Rule]", "lambda"}]}], "}"}]}], ",", 
          "var"}], "]"}]}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6598606463509398`*^9, 3.659860722054142*^9}, {
   3.659860753908966*^9, 3.659860895214111*^9}, {3.6598609917939796`*^9, 
   3.659861069339102*^9}, {3.65986110532203*^9, 3.65986111775967*^9}, 
   3.6598611500294914`*^9, {3.65986119980983*^9, 3.6598612162318883`*^9}, {
   3.6598612631275053`*^9, 3.659861265299389*^9}, {3.6598614331665573`*^9, 
   3.659861461909432*^9}, {3.659864933374468*^9, 3.659864933686971*^9}, 
   3.659865131536273*^9, {3.659865404046544*^9, 3.6598654126716385`*^9}, {
   3.659865622005481*^9, 3.659865642321046*^9}, {3.659865797302887*^9, 
   3.659865877878967*^9}, {3.6598660649300833`*^9, 3.6598660693363795`*^9}, {
   3.659866241559354*^9, 3.6598662780476274`*^9}, {3.659866391657889*^9, 
   3.659866403958869*^9}, {3.6598665649485207`*^9, 3.659866565259739*^9}, {
   3.659866746197262*^9, 3.659866749025276*^9}, 3.6598668696537514`*^9, {
   3.65986703668104*^9, 3.6598670388158865`*^9}, {3.6598670872378874`*^9, 
   3.6598670876922116`*^9}, {3.6598671238888884`*^9, 
   3.6598671283275337`*^9}, {3.659867354290221*^9, 3.6598673898596306`*^9}, {
   3.662099792035598*^9, 3.6620997971606784`*^9}, {3.6621028579566545`*^9, 
   3.6621028872202835`*^9}, {3.6621029247984705`*^9, 3.662102948313961*^9}, {
   3.6621030155572095`*^9, 3.662103062882945*^9}, {3.662103121941097*^9, 
   3.6621031556445932`*^9}, {3.662103199037072*^9, 3.6621032006464615`*^9}, {
   3.6621032328031044`*^9, 3.6621032831840563`*^9}, 3.662103824772875*^9, 
   3.6621040678828335`*^9, 3.6621043065773587`*^9, 3.6621044030027266`*^9, {
   3.66210447886928*^9, 3.6621045106864376`*^9}, 3.662104640761113*^9, {
   3.6621047993922367`*^9, 3.662104799619388*^9}, {3.6621070934725275`*^9, 
   3.662107093690793*^9}, 3.6621137096320868`*^9, {3.6621139279144907`*^9, 
   3.662113928336774*^9}, {3.6621142248809743`*^9, 3.6621142282533484`*^9}, {
   3.6621143056433926`*^9, 3.66211430773689*^9}, {3.662114407923211*^9, 
   3.6621144111564817`*^9}, {3.6621148317664213`*^9, 3.662114833555582*^9}, 
   3.6621150473698597`*^9, {3.6621151366644793`*^9, 3.6621151414228506`*^9}, {
   3.66211533041098*^9, 3.662115330641143*^9}, 3.6621155150324965`*^9, {
   3.6621156052401714`*^9, 3.662115607592836*^9}, {3.662352759639922*^9, 
   3.6623527599523945`*^9}, 3.6623529204219656`*^9, {3.662353846618037*^9, 
   3.662353851965717*^9}, {3.6650487848946447`*^9, 
   3.6650487864571595`*^9}},ExpressionUUID->"a018c05a-20ab-48ac-ae88-\
db7c79f878bd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pq", "[", 
  RowBox[{".27", ",", 
   RowBox[{"tab0", "[", 
    RowBox[{"[", "28", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6623526880735884`*^9, 3.6623526943435297`*^9}, {
  3.662353772683063*^9, 
  3.6623537944209833`*^9}},ExpressionUUID->"706c8139-2275-44db-9f08-\
a599218e3411"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "[", "1", "]"}], "\[Rule]", "6"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "2", "]"}], "\[Rule]", "5.613729339735675`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "3", "]"}], "\[Rule]", "5.098754880303748`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "4", "]"}], "\[Rule]", "6.16426849187041`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "5", "]"}], "\[Rule]", "5.906317261662064`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "6", "]"}], "\[Rule]", "5.762379651469289`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "7", "]"}], "\[Rule]", "5.032426580379179`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "8", "]"}], "\[Rule]", "4.034109109232128`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "9", "]"}], "\[Rule]", "3.054737512289347`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "10", "]"}], "\[Rule]", "2.688402217329546`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "11", "]"}], "\[Rule]", "2.171422686121745`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "12", "]"}], "\[Rule]", "1.6522772947319022`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "13", "]"}], "\[Rule]", "1.3729091511737588`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "14", "]"}], "\[Rule]", "1.152393498096651`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "15", "]"}], "\[Rule]", "0.943244182548787`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "16", "]"}], "\[Rule]", "0.7680291433221149`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "17", "]"}], "\[Rule]", "0.6726321704994171`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "18", "]"}], "\[Rule]", "0.7160707913093639`"}], ",", 
   RowBox[{
    RowBox[{"p", "[", "19", "]"}], "\[Rule]", "0.7755282800961729`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "1", "]"}], "\[Rule]", "0.6405662122825824`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "2", "]"}], "\[Rule]", "0.6280583619152701`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "3", "]"}], "\[Rule]", "0.613301380752369`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "4", "]"}], "\[Rule]", "0.9481627528200773`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "5", "]"}], "\[Rule]", "1.3231420036791803`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "6", "]"}], "\[Rule]", "1.81820903555566`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "7", "]"}], "\[Rule]", "2.3461878939298764`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "8", "]"}], "\[Rule]", "2.8412444692124112`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "9", "]"}], "\[Rule]", "3.2815362652475217`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "10", "]"}], "\[Rule]", "4.732300762577942`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "11", "]"}], "\[Rule]", "6.533106544480354`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "12", "]"}], "\[Rule]", "8.586913874793378`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "13", "]"}], "\[Rule]", "11.2656777846875`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "14", "]"}], "\[Rule]", "16.279206610074922`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "15", "]"}], "\[Rule]", "22.993556094420036`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "16", "]"}], "\[Rule]", "31.81935784911588`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "17", "]"}], "\[Rule]", "46.952206649338834`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "18", "]"}], "\[Rule]", "68.28228436382628`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", "19", "]"}], "\[Rule]", "100.48472559074457`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6623526949216013`*^9, 3.662352770593092*^9, 3.6623529290551324`*^9, {
   3.6623537734643316`*^9, 3.6623537947178793`*^9}, 3.6623538545906816`*^9, 
   3.662353982932211*^9, 3.662981562933138*^9, 3.6629987927388964`*^9, {
   3.665048768535052*^9, 3.665048790175892*^9}, 3.665048980869987*^9, 
   3.6650491834957695`*^9, 3.6650492203385396`*^9, 3.6651316235346565`*^9, 
   3.6652185583021383`*^9, 3.6652355798559012`*^9, 3.66525534337507*^9, 
   3.6654841343376904`*^9},ExpressionUUID->"473d725a-b17e-4fc8-9249-\
0ef2b182e52b"]
}, Open  ]],

Cell["Show matrices", "Text",
 CellChangeTimes->{{3.6573775232146397`*^9, 3.657377632245211*^9}, 
   3.6573777604577875`*^9, {3.6580421376759634`*^9, 3.658042148678512*^9}, {
   3.6598609473735447`*^9, 3.6598609786123514`*^9}, {3.6600316008848686`*^9, 
   3.660031603551757*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"ec6d92b0-e321-462b-a40c-88b25bfb80fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"outmat", "[", 
   RowBox[{"lambda_", ",", "vec_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "n", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", "19"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"wm", "[", "i", "]"}], "=", 
         RowBox[{"vec", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "3"}], "]"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"wf", "[", "i", "]"}], "=", 
         RowBox[{"vec", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "3", "+", "n"}], "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mat", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], 
           RowBox[{"q", "[", "j", "]"}]}], ")"}], " ", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"i", "-", "j"}], ",", "\[Lambda]"}], "]"}], 
         RowBox[{"wf", "[", "i", "]"}], " ", 
         RowBox[{"wm", "[", "j", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}]}], "]"}], "-", 
           RowBox[{"wm", "[", "j", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "2", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}]}], "]"}], "-", 
           RowBox[{"wf", "[", "i", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"var", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"p", "[", "i", "]"}], ",", 
            RowBox[{"9", "/", 
             RowBox[{"Sqrt", "[", "i", "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "2", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"q", "[", "j", "]"}], ",", " ", 
            RowBox[{
             RowBox[{"Sqrt", "[", "j", "]"}], "/", "3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "\[Rule]", "6"}], "}"}], ",", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{"sys", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], "\[Rule]", "6"}], ",", 
             RowBox[{"\[Lambda]", "\[Rule]", "lambda"}]}], "}"}]}], ",", 
          "var"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], 
           RowBox[{"q", "[", "j", "]"}]}], ")"}], " ", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"i", "-", "j"}], ",", "\[Lambda]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "n"}], "}"}]}], "]"}], "//.", " ", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Lambda]", "\[Rule]", "lambda"}], "}"}], ",", "sol"}], 
       "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.660031547402585*^9, 3.660031640060516*^9}, {
   3.660031686962875*^9, 3.6600316918012943`*^9}, {3.660031732791348*^9, 
   3.660031748559354*^9}, {3.660031849664338*^9, 3.6600318682043095`*^9}, {
   3.662099807488889*^9, 3.6620998143639336`*^9}, {3.6621026415498085`*^9, 
   3.6621026587531414`*^9}, {3.6621142166792393`*^9, 3.662114220417814*^9}, {
   3.662114311641636*^9, 3.662114321911374*^9}, {3.6621144004004283`*^9, 
   3.6621144022777586`*^9}, 3.6621157729841523`*^9, 3.6621159900076942`*^9, {
   3.6650487950040803`*^9, 
   3.665048796832261*^9}},ExpressionUUID->"2095fa5b-feb7-40f7-8fe4-\
4982ae78869e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"IntegerPart", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"outmat", "[", 
        RowBox[{".09", ",", 
         RowBox[{"tab0", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "+", ".5"}], "]"}], "/", 
    "100"}], "]"}], "//", "TeXForm"}]], "Input",
 CellChangeTimes->{{3.6600316699046907`*^9, 3.660031675875893*^9}, {
   3.6600317548698225`*^9, 3.660031813545746*^9}, {3.6600318574588327`*^9, 
   3.6600319566289883`*^9}, 3.660031990515107*^9, {3.660032034718424*^9, 
   3.6600320405856543`*^9}, {3.6621007877211404`*^9, 
   3.6621007918530664`*^9}, {3.662102178196475*^9, 3.6621021800715094`*^9}, {
   3.6650488026604156`*^9, 3.665048806019852*^9}, {3.66548409235712*^9, 
   3.665484129718291*^9}},ExpressionUUID->"4fe3b955-64df-4b73-85de-\
a6b4ae7c3488"],

Cell["\<\
\\left(
\\begin{array}{ccccccccccccccccccc}
 3.3 & 2.88 & 2.55 & 1.94 & 1.48 & 1.16 & 0.95 & 0.79 & 0.66 & 0.56 &
   0.49 & 0.44 & 0.39 & 0.35 & 0.31 & 0.28 & 0.26 & 0.24 & 0.23 \\\\
 2.88 & 2.51 & 2.23 & 2.03 & 1.54 & 1.21 & 1. & 0.83 & 0.68 & 0.58 &
   0.51 & 0.46 & 0.4 & 0.36 & 0.32 & 0.3 & 0.27 & 0.26 & 0.24 \\\\
 2.56 & 2.23 & 1.98 & 1.8 & 1.64 & 1.28 & 1.06 & 0.88 & 0.73 & 0.62 &
   0.54 & 0.49 & 0.43 & 0.38 & 0.34 & 0.31 & 0.29 & 0.27 & 0.26 \\\\
 1.95 & 2.04 & 1.81 & 1.64 & 1.5 & 1.4 & 1.16 & 0.96 & 0.8 & 0.67 &
   0.59 & 0.53 & 0.47 & 0.42 & 0.37 & 0.34 & 0.32 & 0.3 & 0.28 \\\\
 1.49 & 1.56 & 1.66 & 1.51 & 1.37 & 1.29 & 1.27 & 1.05 & 0.87 & 0.74
   & 0.65 & 0.58 & 0.52 & 0.46 & 0.41 & 0.38 & 0.35 & 0.33 & 0.31 \\\\
 1.17 & 1.22 & 1.3 & 1.41 & 1.29 & 1.21 & 1.19 & 1.18 & 0.98 & 0.83 &
   0.73 & 0.65 & 0.58 & 0.52 & 0.46 & 0.42 & 0.39 & 0.37 & 0.35 \\\\
 0.97 & 1.01 & 1.08 & 1.17 & 1.28 & 1.2 & 1.18 & 1.17 & 1.17 & 0.99 &
   0.87 & 0.78 & 0.69 & 0.61 & 0.54 & 0.5 & 0.46 & 0.44 & 0.41 \\\\
 0.81 & 0.84 & 0.9 & 0.98 & 1.07 & 1.19 & 1.18 & 1.17 & 1.16 & 1.18 &
   1.04 & 0.93 & 0.82 & 0.73 & 0.65 & 0.6 & 0.55 & 0.52 & 0.49 \\\\
 0.67 & 0.7 & 0.75 & 0.82 & 0.89 & 1. & 1.18 & 1.17 & 1.16 & 1.18 &
   1.24 & 1.11 & 0.99 & 0.88 & 0.78 & 0.72 & 0.66 & 0.62 & 0.59 \\\\
 0.58 & 0.6 & 0.64 & 0.7 & 0.76 & 0.85 & 1.01 & 1.2 & 1.19 & 1.21 &
   1.27 & 1.36 & 1.21 & 1.07 & 0.95 & 0.88 & 0.81 & 0.76 & 0.72 \\\\
 0.51 & 0.54 & 0.57 & 0.62 & 0.68 & 0.76 & 0.9 & 1.06 & 1.26 & 1.28 &
   1.35 & 1.45 & 1.54 & 1.37 & 1.21 & 1.12 & 1.03 & 0.97 & 0.91 \\\\
 0.46 & 0.48 & 0.51 & 0.55 & 0.6 & 0.68 & 0.8 & 0.95 & 1.13 & 1.37 &
   1.44 & 1.54 & 1.64 & 1.75 & 1.55 & 1.43 & 1.32 & 1.24 & 1.17 \\\\
 0.41 & 0.43 & 0.45 & 0.49 & 0.54 & 0.6 & 0.71 & 0.85 & 1. & 1.22 &
   1.54 & 1.65 & 1.75 & 1.87 & 1.98 & 1.83 & 1.69 & 1.58 & 1.49 \\\\
 0.36 & 0.38 & 0.4 & 0.44 & 0.48 & 0.54 & 0.64 & 0.76 & 0.9 & 1.09 &
   1.37 & 1.76 & 1.87 & 2. & 2.12 & 2.34 & 2.16 & 2.03 & 1.91 \\\\
 0.32 & 0.34 & 0.36 & 0.39 & 0.43 & 0.48 & 0.57 & 0.67 & 0.8 & 0.97 &
   1.22 & 1.56 & 1.99 & 2.12 & 2.25 & 2.49 & 2.75 & 2.58 & 2.43 \\\\
 0.29 & 0.31 & 0.32 & 0.35 & 0.39 & 0.43 & 0.51 & 0.61 & 0.72 & 0.88
   & 1.1 & 1.42 & 1.8 & 2.3 & 2.44 & 2.7 & 2.98 & 3.35 & 3.16 \\\\
 0.26 & 0.28 & 0.29 & 0.32 & 0.35 & 0.39 & 0.46 & 0.55 & 0.65 & 0.79
   & 1. & 1.28 & 1.63 & 2.07 & 2.64 & 2.92 & 3.22 & 3.62 & 4.08 \\\\
 0.25 & 0.26 & 0.27 & 0.3 & 0.32 & 0.36 & 0.43 & 0.51 & 0.61 & 0.74 &
   0.93 & 1.19 & 1.51 & 1.93 & 2.45 & 3.25 & 3.59 & 4.03 & 4.54 \\\\
 0.23 & 0.24 & 0.25 & 0.28 & 0.3 & 0.34 & 0.4 & 0.47 & 0.56 & 0.69 &
   0.86 & 1.11 & 1.41 & 1.8 & 2.29 & 3.02 & 4. & 4.49 & 5.07 \\\\
\\end{array}
\\right)\
\>", "Output",
 CellChangeTimes->{
  3.665484134645913*^9},ExpressionUUID->"f1e3b45d-3524-436a-b851-\
5e5b63dc6097"]
}, Open  ]],

Cell["\<\
The following routine takes a given parameter lambda and a given vector of \
data (one country) and compute the correlation (ef, em)
in detail : 
  There is a loop where we draw nb pairs (ef, em). For each woman i
it first draws the education ef  from its observed distribution, using the \
command RandomChoice
then, given the education of that girl, it computes the probability g[j] to \
meet a guy of education j
We next draw a guy for her, given these probabilities
When the loop is finished, we computed the correlation between the two \
education levels\
\>", "Text",
 CellChangeTimes->{{3.6573771248393126`*^9, 3.657377439868399*^9}, 
   3.6573777564318542`*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"e63d43c3-377b-4dd1-8713-ce4636166c18"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nb", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"co", "[", 
   RowBox[{"lambda_", ",", "vec_", ",", "weights_", ",", "name_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tp", ",", "A", ",", "B"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ef", "[", "i", "]"}], "=", 
         RowBox[{
          RowBox[{"RandomChoice", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"vec", "[", 
                RowBox[{"[", "4", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "5", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "6", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "7", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "8", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "9", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "10", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "11", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "12", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "13", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "14", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "15", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "16", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "17", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "18", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "19", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "20", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "21", "]"}], "]"}], ",", 
               RowBox[{"vec", "[", 
                RowBox[{"[", "22", "]"}], "]"}]}], "}"}], "->", 
             RowBox[{"{", 
              RowBox[{
              "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6",
                ",", "7", ",", "8", ",", "9", ",", "10", ",", "11", ",", "12",
                ",", "13", ",", "14", ",", "15", ",", "16", ",", "17", ",", 
               "18"}], "}"}]}], ",", "1"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"g", "[", "j_", "]"}], ":=", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", 
            RowBox[{
             RowBox[{"ef", "[", "i", "]"}], "+", "1"}], "]"}], " ", 
           RowBox[{"q", "[", 
            RowBox[{"j", "+", "1"}], "]"}], " ", 
           RowBox[{"f", "[", 
            RowBox[{
             RowBox[{"j", "-", 
              RowBox[{"ef", "[", "i", "]"}]}], ",", "lambda"}], "]"}], " ", 
           RowBox[{"vec", "[", 
            RowBox[{"[", 
             RowBox[{"23", "+", "j"}], "]"}], "]"}]}], "/.", "weights"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"em", "[", "i", "]"}], "=", 
         RowBox[{
          RowBox[{"RandomChoice", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"g", "[", "0", "]"}], " ", ",", 
               RowBox[{"g", "[", "1", "]"}], ",", 
               RowBox[{"g", "[", "2", "]"}], ",", 
               RowBox[{"g", "[", "3", "]"}], ",", 
               RowBox[{"g", "[", "4", "]"}], ",", 
               RowBox[{"g", "[", "5", "]"}], ",", 
               RowBox[{"g", "[", "6", "]"}], ",", 
               RowBox[{"g", "[", "7", "]"}], ",", 
               RowBox[{"g", "[", "8", "]"}], ",", 
               RowBox[{"g", "[", "9", "]"}], ",", 
               RowBox[{"g", "[", "10", "]"}], ",", 
               RowBox[{"g", "[", "11", "]"}], ",", 
               RowBox[{"g", "[", "12", "]"}], ",", 
               RowBox[{"g", "[", "13", "]"}], ",", 
               RowBox[{"g", "[", "14", "]"}], ",", 
               RowBox[{"g", "[", "15", "]"}], ",", 
               RowBox[{"g", "[", "16", "]"}], ",", 
               RowBox[{"g", "[", "17", "]"}], ",", 
               RowBox[{"g", "[", "18", "]"}]}], "}"}], "->", 
             RowBox[{"{", 
              RowBox[{
              "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6",
                ",", "7", ",", "8", ",", "9", ",", "10", ",", "11", ",", "12",
                ",", "13", ",", "14", ",", "15", ",", "16", ",", "17", ",", 
               "18"}], "}"}]}], ",", "1"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"A", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"100", " ", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"ef", "[", "k", "]"}], "\[Equal]", 
                 RowBox[{"j", "-", "1"}]}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"em", "[", "k", "]"}], "==", 
                 RowBox[{"i", "-", "1"}]}]}], ",", "1", ",", "0"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", "nb"}], "}"}]}], "]"}], "/", 
           "nb"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "19"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "19"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"B", "=", 
      RowBox[{"Import", "[", 
       RowBox[{"name", ",", "\"\<Table\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Correlation", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"ef", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"em", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}]}], "]"}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"N", "[", 
        RowBox[{"SpearmanRho", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"ef", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"em", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}]}], "]"}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Norm", "[", 
        RowBox[{
         RowBox[{"A", "-", "B"}], ",", "\"\<Frobenius\>\""}], "]"}], ",", 
       RowBox[{
        RowBox[{"Mantel", "[", 
         RowBox[{"A", ",", "B", ",", "10"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6573689219212584`*^9, 3.6573689340967684`*^9}, {
   3.657369096001424*^9, 3.6573691069718957`*^9}, {3.6573733944601717`*^9, 
   3.657373556939031*^9}, {3.6573736004867964`*^9, 3.657373604424365*^9}, {
   3.657373644638093*^9, 3.657373644966221*^9}, {3.657373766581539*^9, 
   3.6573738771500673`*^9}, {3.6573739258765836`*^9, 3.657374007183479*^9}, {
   3.6573740450803823`*^9, 3.6573742678555703`*^9}, {3.6573743201055593`*^9, 
   3.6573743975413265`*^9}, 3.6573745959857597`*^9, {3.657374653063797*^9, 
   3.657374707373395*^9}, {3.6573749190004897`*^9, 3.657374946752737*^9}, {
   3.6573756612070694`*^9, 3.6573756658605757`*^9}, {3.657376118250209*^9, 
   3.6573761185877056`*^9}, {3.6573774471176205`*^9, 3.657377513735433*^9}, {
   3.6573776877405443`*^9, 3.657377687959299*^9}, 3.6573777189283195`*^9, {
   3.6573777854764013`*^9, 3.6573778318524475`*^9}, {3.657378125093435*^9, 
   3.657378137156063*^9}, {3.65804205923333*^9, 3.6580420606113043`*^9}, 
   3.6580421017127523`*^9, {3.6580421538541784`*^9, 3.6580421641974545`*^9}, {
   3.6580422065528135`*^9, 3.658042207486472*^9}, {3.659860625006965*^9, 
   3.6598606265225935`*^9}, {3.659861313721543*^9, 3.659861362346198*^9}, {
   3.6598613926746607`*^9, 3.659861393752798*^9}, 3.6598615264498672`*^9, 
   3.6598615798765707`*^9, {3.6598616916353135`*^9, 3.6598616990104094`*^9}, 
   3.659864405726987*^9, {3.659867589319317*^9, 3.659867591140603*^9}, {
   3.661778710203576*^9, 3.6617787103917103`*^9}, {3.6618795343554535`*^9, 
   3.661879535933592*^9}, {3.662099831233713*^9, 3.6620998372338276`*^9}, {
   3.662353498541319*^9, 3.6623535410870786`*^9}, {3.662353675612245*^9, 
   3.6623536844810433`*^9}, {3.6623537518344793`*^9, 3.662353757350154*^9}, {
   3.662353938624208*^9, 3.6623539394679794`*^9}, {3.6650488285781746`*^9, 
   3.665048859750354*^9}, {3.6650491615194225`*^9, 3.665049161706869*^9}, {
   3.665131413393039*^9, 3.665131488847348*^9}, {3.665131560065217*^9, 
   3.6651316331583033`*^9}, {3.6651316829809513`*^9, 3.665131749582012*^9}, {
   3.665131788551194*^9, 3.6651317910043435`*^9}, 3.665131896530241*^9, {
   3.665132364857629*^9, 3.665132365014757*^9}, {3.665132577537248*^9, 
   3.6651326317158184`*^9}, {3.6651327058591576`*^9, 
   3.6651327060310354`*^9}, {3.665133941669377*^9, 3.6651339794655194`*^9}, {
   3.6651340264663267`*^9, 3.6651340279350786`*^9}, {3.665134109024417*^9, 
   3.665134143501463*^9}, {3.6651360573705215`*^9, 3.665136080944762*^9}, {
   3.66513687702843*^9, 3.665136898981753*^9}, 3.6651389784296436`*^9, {
   3.6651391028600645`*^9, 3.6651391140633287`*^9}, {3.665139206394066*^9, 
   3.6651392065503407`*^9}, 3.6651403008314342`*^9, {3.6651477488335156`*^9, 
   3.6651477502975583`*^9}, 3.6651484530442305`*^9, 3.6652185544023685`*^9, 
   3.665237280384523*^9, {3.665255310602229*^9, 
   3.665255311055357*^9}},ExpressionUUID->"f893e209-70cc-41c2-b314-\
e46fb9081f75"],

Cell["\<\
We compute the correlation between ef nd em for different lambdas\
\>", "Text",
 CellChangeTimes->{{3.6573775232146397`*^9, 3.657377632245211*^9}, 
   3.6573777604577875`*^9, {3.6580421376759634`*^9, 3.658042148678512*^9}, {
   3.662353883149841*^9, 3.662353889212388*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"cb17ea4d-220f-475a-b70d-86a923f606ba"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"co", "[", 
     RowBox[{"lam", ",", 
      RowBox[{"tab0", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"pq", "[", 
       RowBox[{"lam", ",", 
        RowBox[{"tab0", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"tab0", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"lam", ",", "0.", ",", ".3", ",", ".01"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.66187932469098*^9, 3.66187933080042*^9}, 
   3.6620999995530796`*^9, {3.662353643119893*^9, 3.662353648432476*^9}, {
   3.6651325015771666`*^9, 3.66513251348355*^9}, {3.665132717593631*^9, 
   3.6651327238280673`*^9}, {3.665139118454021*^9, 3.665139118875845*^9}, 
   3.665218591696638*^9},ExpressionUUID->"dfea53b1-0cdf-40d8-b24f-\
24a630f53943"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132519374218*^9, 3.6651326405033646`*^9, 
  3.6651327243905954`*^9, 3.665147756549952*^9, 3.665148456684785*^9, 
  3.6652185585252833`*^9, 3.665235580054044*^9, 
  3.6652553435938177`*^9},ExpressionUUID->"0cda0d7d-4cec-4d82-a75f-\
ef35c52c3f38"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132519374218*^9, 3.6651326405033646`*^9, 
  3.6651327243905954`*^9, 3.665147756549952*^9, 3.665148456684785*^9, 
  3.6652185585252833`*^9, 3.665235580054044*^9, 
  3.665255362406504*^9},ExpressionUUID->"fc81178e-1fa9-4505-9f19-\
4b4962e7f927"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132519374218*^9, 3.6651326405033646`*^9, 
  3.6651327243905954`*^9, 3.665147756549952*^9, 3.665148456684785*^9, 
  3.6652185585252833`*^9, 3.665235580054044*^9, 
  3.6652553719309287`*^9},ExpressionUUID->"0022e20c-79ca-41b6-8372-\
5316f79a9040"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132519374218*^9, 3.6651326405033646`*^9, 
  3.6651327243905954`*^9, 3.665147756549952*^9, 3.665148456684785*^9, 
  3.6652185585252833`*^9, 3.665235580054044*^9, 
  3.665255371962183*^9},ExpressionUUID->"a309af74-56b0-4778-835b-\
dbbaa1922a34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.009571577150547532`"}], ",", "0.03816781859128514`", ",", 
   "0.1153283107315026`", ",", "0.18243367169655778`", ",", 
   "0.20865924582915038`", ",", "0.2810794709336878`", ",", 
   "0.32583952910113906`", ",", "0.3970423999204576`", ",", 
   "0.4398866061132685`", ",", "0.4885243829756554`", ",", 
   "0.5264526792118551`", ",", "0.5666497507185134`", ",", 
   "0.5868716360145733`", ",", "0.6190184905391838`", ",", 
   "0.6533408750025952`", ",", "0.6876787137798327`", ",", 
   "0.6944216353311732`", ",", "0.7274108831659173`", ",", 
   "0.7388039340340037`", ",", "0.7553069357413859`", ",", 
   "0.7674579322019357`", ",", "0.7772286631599452`", ",", 
   "0.7890248044633429`", ",", "0.802059488263319`", ",", 
   "0.810128728441145`", ",", "0.8137232104589311`", ",", 
   "0.8256968347794674`", ",", "0.830772016167866`", ",", 
   "0.8400140140249283`", ",", "0.8449827973811381`", ",", 
   "0.850854592215266`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6618794107373714`*^9, 3.6618795401992064`*^9, 3.6620998556986933`*^9, 
   3.662099957838204*^9, {3.662099992740453*^9, 3.6621000002309875`*^9}, 
   3.6621002364916444`*^9, 3.662100381931565*^9, 3.6621023259394217`*^9, 
   3.6621030671798096`*^9, 3.662103138269415*^9, 3.662103204599621*^9, 
   3.6621143297428417`*^9, 3.6621153366565695`*^9, 3.662352783493927*^9, {
   3.6623535235825205`*^9, 3.662353526441907*^9}, {3.6623536502483406`*^9, 
   3.662353688621692*^9}, 3.6623538639756885`*^9, 3.6623540734807825`*^9, 
   3.6629816575787344`*^9, 3.662998885920208*^9, 3.6650488696410284`*^9, 
   3.6650489822918715`*^9, 3.665049207650915*^9, 3.6650493136276636`*^9, 
   3.6651325231773214`*^9, 3.6651326448471384`*^9, 3.6651330442695246`*^9, 
   3.6651477889039392`*^9, 3.665148515523881*^9, 3.6652185651151595`*^9, 
   3.6652355892435427`*^9, 
   3.665255628048276*^9},ExpressionUUID->"643b25a0-8493-43e5-a5f8-\
03ce66c64a85"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7F+WrAxzntW8HyrgwPfWvHJ312J7CJfD4R/P
01/qbXuhfAEHDrkLfX8ij0P5Ig6T+XPmRWw9BeVLOFzSPb/f5O9FKF/Gof+D
H1ffrStQvoJDocamNpXMm1C+kkOh7Fk1KfU7UL6KA28p97HfzvehfDWHnAxm
r803HkD5Gg7Cb4pX/FN8BOVrOQTblbAtPw7j6zgca+2/+//cYyhfzyH5Woa8
9osnUL6BA+d9q1NljM+gfEMHE+s1OzZbwPhGDp3ldgaf3Z5D+cYO7gtvqXos
gfFNHAoL8oortV9A+aYOTfN+v2fuh/HNHP6oWC7luw/jmztoP4n5tMH+JZRv
4XDG6OOKilUwvqXD1F430clvYHwrhz+Rsk6sXK+gfGuH+dY7j0jnwPg2DlHv
fxuunwrj2zpkp50VTH0I49s5SL3gjZXkeg3l2zuEv3yWYWz12h4AdWKMZg==

      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0., 31.}, {-0.009571577150547532, 0.850854592215266}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6618794107373714`*^9, 3.6618795401992064`*^9, 3.6620998556986933`*^9, 
   3.662099957838204*^9, {3.662099992740453*^9, 3.6621000002309875`*^9}, 
   3.6621002364916444`*^9, 3.662100381931565*^9, 3.6621023259394217`*^9, 
   3.6621030671798096`*^9, 3.662103138269415*^9, 3.662103204599621*^9, 
   3.6621143297428417`*^9, 3.6621153366565695`*^9, 3.662352783493927*^9, {
   3.6623535235825205`*^9, 3.662353526441907*^9}, {3.6623536502483406`*^9, 
   3.662353688621692*^9}, 3.6623538639756885`*^9, 3.6623540734807825`*^9, 
   3.6629816575787344`*^9, 3.662998885920208*^9, 3.6650488696410284`*^9, 
   3.6650489822918715`*^9, 3.665049207650915*^9, 3.6650493136276636`*^9, 
   3.6651325231773214`*^9, 3.6651326448471384`*^9, 3.6651330442695246`*^9, 
   3.6651477889039392`*^9, 3.665148515523881*^9, 3.6652185651151595`*^9, 
   3.6652355892435427`*^9, 
   3.6652556282357635`*^9},ExpressionUUID->"b549b084-27ce-4862-b15a-\
4a68415f12cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"co", "[", 
     RowBox[{"lam", ",", 
      RowBox[{"tab0", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"pq", "[", 
       RowBox[{"lam", ",", 
        RowBox[{"tab0", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"tab0", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"lam", ",", "0.", ",", ".3", ",", ".01"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{
  3.665048925561614*^9, {3.665132504577216*^9, 3.6651325166398134`*^9}, {
   3.6651327289756885`*^9, 3.665132729303815*^9}, {3.6651391239773808`*^9, 
   3.6651391250085926`*^9}, 
   3.6651484105846033`*^9},ExpressionUUID->"ffc38958-b8c7-4a08-af23-\
58cb2be80500"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6651325290367556`*^9, 3.6651326492534494`*^9, 
  3.6651330444156227`*^9, 3.665147789080065*^9, 3.6652185655825033`*^9, 
  3.6652355896848536`*^9, 
  3.6652556285170326`*^9},ExpressionUUID->"c95026a7-f2de-4e81-81cb-\
b88816a5279c"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6651325290367556`*^9, 3.6651326492534494`*^9, 
  3.6651330444156227`*^9, 3.665147789080065*^9, 3.6652185655825033`*^9, 
  3.6652355896848536`*^9, 
  3.665255645038836*^9},ExpressionUUID->"b18d0c2b-c9cb-4188-9332-\
620629eed59a"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6651325290367556`*^9, 3.6651326492534494`*^9, 
  3.6651330444156227`*^9, 3.665147789080065*^9, 3.6652185655825033`*^9, 
  3.6652355896848536`*^9, 
  3.665255653585782*^9},ExpressionUUID->"e93c74ef-4396-4db5-8e87-\
361c2a3f37bc"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6651325290367556`*^9, 3.6651326492534494`*^9, 
  3.6651330444156227`*^9, 3.665147789080065*^9, 3.6652185655825033`*^9, 
  3.6652355896848536`*^9, 
  3.665255653617031*^9},ExpressionUUID->"7513bee6-66f2-4bba-b87d-\
e0a374c09ca2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.011090340155315596`", ",", "0.04995020796568608`", ",", 
   "0.1280072473802215`", ",", "0.14945805855405309`", ",", 
   "0.22151501347051125`", ",", "0.28584959509455393`", ",", 
   "0.3337920642804641`", ",", "0.3760436984664695`", ",", 
   "0.4296551457350066`", ",", "0.475740798305279`", ",", 
   "0.5036037890247047`", ",", "0.5445850956178617`", ",", 
   "0.5680399873010634`", ",", "0.6026911120780534`", ",", 
   "0.641217274539582`", ",", "0.6558852301863407`", ",", 
   "0.6794378496692137`", ",", "0.7025094936953532`", ",", 
   "0.7125699472675818`", ",", "0.7434942552629927`", ",", 
   "0.7470431000636306`", ",", "0.7553310240728254`", ",", 
   "0.7780984462007703`", ",", "0.7914984199994062`", ",", 
   "0.7972508197043473`", ",", "0.8074618673931319`", ",", 
   "0.8103846722806651`", ",", "0.8259706614024348`", ",", 
   "0.8330183083138307`", ",", "0.8404691505120032`", ",", 
   "0.8454404222610499`"}], "}"}]], "Output",
 CellChangeTimes->{3.665048927733453*^9, 3.6650489838075376`*^9, 
  3.6650494079938726`*^9, 3.665132532943061*^9, 3.6651326536284904`*^9, 
  3.665133361874524*^9, 3.6651478216611586`*^9, 3.665218574875063*^9, 
  3.665235598631542*^9, 
  3.6652558929236774`*^9},ExpressionUUID->"07afd5c3-5980-4db6-b77f-\
b1efde94d122"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7NeLqjl1bGuzhwo4XDH2uC00eSWUz+HQIjx5
XlfSAShfwOFXwzmBQsXDUL6IQ/oTs7mzos5A+RIOjYkLJGO8L0H5Mg7R794n
34y5CuUrOMz9uHGapOANKF/JYUH0fe+K+ttQvorDZda2js6ie1C+msMdsYaN
rbIPoHwNBwbtTztscx9C+VoOrC84jJJ0H0H5Og56j/7ds/N8DOXrOaQ+/iF2
q+UJlG/gUNC7iZX5L4xv6NBy9n/hl71PoXwjB89FEw2+Vj2D8o0d/vOW1Maf
hfFNHHRPPS7bcuo5lG/qEGaZ/+7YcxjfzOF8w8Hvq7VfQPnmDu9YC7bpPYPx
LRz2lE6v+xL8Esq3dBC6s0pNpBnGt3IQ5ld33XUNxrd2kGIUubb6HYxv4/B+
pytbVN4rKN/WwWj1UyaxFTC+ncO9e+H98k9hfHsHtpouoZu8r+0BTWOORQ==

      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0., 31.}, {0, 0.8454404222610499}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.665048927733453*^9, 3.6650489838075376`*^9, 
  3.6650494079938726`*^9, 3.665132532943061*^9, 3.6651326536284904`*^9, 
  3.665133361874524*^9, 3.6651478216611586`*^9, 3.665218574875063*^9, 
  3.665235598631542*^9, 
  3.665255892970543*^9},ExpressionUUID->"c9a3668e-49eb-4a7a-a67f-\
d58304234b6a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"co", "[", 
     RowBox[{"lam", ",", 
      RowBox[{"tab0", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"pq", "[", 
       RowBox[{"lam", ",", 
        RowBox[{"tab0", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"tab0", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"lam", ",", "0.", ",", ".3", ",", ".01"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.6651326561343594`*^9, 3.665132690119052*^9}, {
   3.6651327317882147`*^9, 3.665132732600741*^9}, {3.6651391287586565`*^9, 
   3.6651391296024137`*^9}, 
   3.6651484037677794`*^9},ExpressionUUID->"6eed27f0-cd9b-42c9-9779-\
7270fed2e62a"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132657024996*^9, 3.665133362017625*^9, 
  3.665134178689314*^9, 3.6651345771982017`*^9, 3.665147821867304*^9, 
  3.6651485156664906`*^9, 3.6652185750301714`*^9, 3.6652355987756443`*^9, 
  3.665255893064291*^9},ExpressionUUID->"1e3b9981-42ff-4add-b13b-\
d4fce01b86cb"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132657024996*^9, 3.665133362017625*^9, 
  3.665134178689314*^9, 3.6651345771982017`*^9, 3.665147821867304*^9, 
  3.6651485156664906`*^9, 3.6652185750301714`*^9, 3.6652355987756443`*^9, 
  3.665255909814451*^9},ExpressionUUID->"e6114e25-8160-4894-b7ad-\
7f7ea56b11f7"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132657024996*^9, 3.665133362017625*^9, 
  3.665134178689314*^9, 3.6651345771982017`*^9, 3.665147821867304*^9, 
  3.6651485156664906`*^9, 3.6652185750301714`*^9, 3.6652355987756443`*^9, 
  3.6652559183614116`*^9},ExpressionUUID->"ccd42afa-743a-4354-a1e0-\
001241ee6900"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665132657024996*^9, 3.665133362017625*^9, 
  3.665134178689314*^9, 3.6651345771982017`*^9, 3.665147821867304*^9, 
  3.6651485156664906`*^9, 3.6652185750301714`*^9, 3.6652355987756443`*^9, 
  3.665255918392665*^9},ExpressionUUID->"0302fecb-e152-4b34-8d2f-\
36cb5620fdf5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11.047540714498409`", ",", "10.658171214542387`", ",", 
   "10.28202163188251`", ",", "9.810760645255797`", ",", "9.813146938597216`",
    ",", "9.454418429417016`", ",", "9.036867623159038`", ",", 
   "8.818297592988117`", ",", "8.686189592594673`", ",", "8.296474024457616`",
    ",", "8.124515384839885`", ",", "7.6721005362612384`", ",", 
   "8.004192916122152`", ",", "7.62761923790772`", ",", "7.531173722501693`", 
   ",", "7.585345189145976`", ",", "7.249252170982882`", ",", 
   "6.882100932019236`", ",", "6.99717067381524`", ",", "7.178274879001222`", 
   ",", "7.502616226257344`", ",", "7.070046904971704`", ",", 
   "6.881370389573574`", ",", "6.981628824171331`", ",", "6.990063936653226`",
    ",", "6.825610466361233`", ",", "6.808530945695992`", ",", 
   "7.1115541647729845`", ",", "6.982454399314037`", ",", "6.80246776093059`",
    ",", "6.86530228311179`"}], "}"}]], "Output",
 CellChangeTimes->{3.6651326613531456`*^9, 3.6651336740719366`*^9, 
  3.665134486276171*^9, 3.665134884945019*^9, 3.6651478541971693`*^9, 
  3.6651485761705523`*^9, 3.6652185844798555`*^9, 3.665235607452609*^9, 
  3.665256158386977*^9},ExpressionUUID->"af9e9ba7-1ffd-4ac3-a241-\
ee1fd2c8aed1"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7Pv/r3YMl1BzgAo4zHV0vvg7QBXK53CITVut
nDpBBcoXcLjR/IFFZr4ylC/iYGiz4nTIAhhfwiFf3Ktj5QslKF/GYXm9esAD
IRhfwUGi/8Oz74sUoXwlhwJJNruQeBhfxSElsK7w9HQFKF/N4VUFc/UBexhf
w+FeWbW89QY5KF/LwdD29SRVJpi8jsPZuSLz1jXB5PUcNvVJMb6Rh/ENHH4y
bdyVEg7jGzrEBnB/s/4vA+UbOZzSqS53bZeG8o0dwl2U/KX+wvgmDhc45mzo
3QZTb+oQf/vH5bVMMPPMHAo0LBJ2ucPkzR3y2mZ/bW2D6bdwuNHoJG3wFsa3
dJhbLxx0+SuMb+Xwg63xSo4vjG/t8MDVrfO9NYxv4/Bpl6ujdRHMfFuHB6Wr
2zjeweTtHCy0rkrvMoXx7R2UqmzOCpZJOwAA3DZz3g==
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 6.590214113252199},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0., 31.}, {6.80246776093059, 11.047540714498409`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6651326613531456`*^9, 3.6651336740719366`*^9, 
  3.665134486276171*^9, 3.665134884945019*^9, 3.6651478541971693`*^9, 
  3.6651485761705523`*^9, 3.6652185844798555`*^9, 3.665235607452609*^9, 
  3.6652561584182267`*^9},ExpressionUUID->"393ebc7e-b902-4f7b-b5bc-\
a4b400bad3b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"co", "[", 
     RowBox[{"lam", ",", 
      RowBox[{"tab0", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"pq", "[", 
       RowBox[{"lam", ",", 
        RowBox[{"tab0", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"tab0", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "4", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"lam", ",", "0.", ",", ".3", ",", ".01"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.665134266234234*^9, 3.665134276484334*^9}, {
   3.665139133149292*^9, 3.665139134211809*^9}, 
   3.6651481614021273`*^9},ExpressionUUID->"9cb02491-60fa-4ee7-90cd-\
c74850ad77e3"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665134533890018*^9, 3.665134885085664*^9, 
  3.665136144414565*^9, 3.665136908050867*^9, 3.6651392125190973`*^9, 
  3.665140306456495*^9, 3.6651478543782973`*^9, 3.6651481635856714`*^9, 
  3.665148576308649*^9, 3.6652185846279593`*^9, 3.665235607593709*^9, 
  3.6652561585432296`*^9},ExpressionUUID->"9d9f631b-b506-44ff-b9ec-\
a8541c356ce5"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665134533890018*^9, 3.665134885085664*^9, 
  3.665136144414565*^9, 3.665136908050867*^9, 3.6651392125190973`*^9, 
  3.665140306456495*^9, 3.6651478543782973`*^9, 3.6651481635856714`*^9, 
  3.665148576308649*^9, 3.6652185846279593`*^9, 3.665235607593709*^9, 
  3.665256175293705*^9},ExpressionUUID->"ef0e03ac-c187-4e66-8885-\
ba900e015172"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665134533890018*^9, 3.665134885085664*^9, 
  3.665136144414565*^9, 3.665136908050867*^9, 3.6651392125190973`*^9, 
  3.665140306456495*^9, 3.6651478543782973`*^9, 3.6651481635856714`*^9, 
  3.665148576308649*^9, 3.6652185846279593`*^9, 3.665235607593709*^9, 
  3.6652561840181847`*^9},ExpressionUUID->"f4724528-08e6-4b7c-beb2-\
8a6ff1902329"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665134533890018*^9, 3.665134885085664*^9, 
  3.665136144414565*^9, 3.665136908050867*^9, 3.6651392125190973`*^9, 
  3.665140306456495*^9, 3.6651478543782973`*^9, 3.6651481635856714`*^9, 
  3.665148576308649*^9, 3.6652185846279593`*^9, 3.665235607593709*^9, 
  3.665256184049436*^9},ExpressionUUID->"615bca55-6125-4d02-8e01-\
b1c737bdb403"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6814291875128138`", ",", "0.6936788764769012`", ",", 
   "0.7583647311273991`", ",", "0.7561218107891907`", ",", 
   "0.8197729619809345`", ",", "0.8252407946176902`", ",", 
   "0.8529735516221372`", ",", "0.8637204660912523`", ",", 
   "0.8651387560055716`", ",", "0.8910213677200518`", ",", 
   "0.901079522657658`", ",", "0.8762467856848126`", ",", 
   "0.887781836914192`", ",", "0.9146883918635257`", ",", 
   "0.9064729504844184`", ",", "0.8843810247536329`", ",", 
   "0.8845112124419158`", ",", "0.8763731266770511`", ",", 
   "0.876503423429035`", ",", "0.8896206752641781`", ",", 
   "0.8747919698715467`", ",", "0.8516951943539458`", ",", 
   "0.8644099305142251`", ",", "0.8563794736598996`", ",", 
   "0.8486971147081848`", ",", "0.8209538934342233`", ",", 
   "0.8211689065796209`", ",", "0.8115809823754705`", ",", 
   "0.7962970128058473`", ",", "0.7963841358713704`", ",", 
   "0.8035043811431862`"}], "}"}]], "Output",
 CellChangeTimes->{3.6651345651236725`*^9, 3.665135195757578*^9, 
  3.6651364455040407`*^9, 3.665138432607363*^9, 3.66513951911963*^9, 
  3.6651406336286483`*^9, 3.665147886447055*^9, 3.6651481959992795`*^9, 
  3.665148635794051*^9, 3.665218593493532*^9, 3.665235616367133*^9, 
  3.6652564238091636`*^9},ExpressionUUID->"05b7243a-a8df-4163-8904-\
02bc919327ef"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7AM4Y6e6nHtqDxVwsJzHwz3P6BmUz+FQZHlF
ps3lBZQv4BBgoRKnZgTjizgo+u5unGL9CsqXcDBewZYUnwHjyzhctp1k0O/9
GspXcGB7Fy41czGMr+TgWvmxwnw9jK/i4LfIx86++Q2Ur+agJSe7c8lVGF/D
oWrn901mXDC+lsPm9wUlWzNgfB2HlVuVpiu4voXy9Ry0HBf2X2aE8Q0cYhcF
5N/0gak3dPB28Sl95QvjGzlUVB1dbs8N4xs72GzzexHAA+ObOFyOcT5+tBzG
N3W4cGvNLu9/MPebOQQq73UXc4TxzR1ert3DbL8SxrdwYN7B9bY0Hca3dHhh
9OdmmwaMb+XAE1sl6egKCz9rh608J5hZ3GF8G4eYMu11FT9eQvm2DlGvau47
V8P4dg42d4On/oLz7R16a55d9Nv20h4AMdqHdA==
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.6697662272952782},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0., 31.}, {0.6814291875128138, 0.9146883918635257}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6651345651236725`*^9, 3.665135195757578*^9, 
  3.6651364455040407`*^9, 3.665138432607363*^9, 3.66513951911963*^9, 
  3.6651406336286483`*^9, 3.665147886447055*^9, 3.6651481959992795`*^9, 
  3.665148635794051*^9, 3.665218593493532*^9, 3.665235616367133*^9, 
  3.6652564238404164`*^9},ExpressionUUID->"2f43b5e0-070f-468b-b0aa-\
faad7de7625e"]
}, Open  ]],

Cell["\<\
The following routine build a table \"outcome\" of values of the correlation \
(ef, em) for different values of lambda (k represents lambda, with increments \
of 1/100)
Then we look in the table the nearest value to the empirical correlation
The position of this value in the table gives the corresponding value of \
lambda (/100)\
\>", "Text",
 CellChangeTimes->{{3.6573775232146397`*^9, 3.657377632245211*^9}, 
   3.6573777604577875`*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"e3bb8231-0dc9-4ac7-843f-992a94f3a0e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"best", "[", "ve_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"outcome", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"co", "[", 
          RowBox[{"k", ",", "ve", ",", 
           RowBox[{"pq", "[", 
            RowBox[{"k", ",", "ve"}], "]"}], ",", 
           RowBox[{"ve", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", ".3", ",", ".01"}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ne", "=", 
      RowBox[{"Nearest", "[", 
       RowBox[{"outcome", ",", 
        RowBox[{"ve", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{"outcome", ",", 
           RowBox[{"ne", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/", "100"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6573761236607294`*^9, 3.6573761266764317`*^9}, {
   3.657376315194044*^9, 3.6573763451163516`*^9}, {3.6573764120267267`*^9, 
   3.6573764157142954`*^9}, {3.6598617657731743`*^9, 3.65986177547641*^9}, {
   3.6598651948634195`*^9, 3.6598651960821605`*^9}, 3.6621004798460336`*^9, {
   3.6621023176893525`*^9, 3.662102319579996*^9}, {3.6621145240702224`*^9, 
   3.662114525134988*^9}, {3.6651417567381735`*^9, 3.665141771275768*^9}, {
   3.6651422476299267`*^9, 3.665142248223665*^9}, {3.665149280575741*^9, 
   3.665149293796096*^9}},ExpressionUUID->"742636b5-6e28-4648-9bb6-\
6eca412ff52d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rbest", "[", "ve_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"outcome", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"co", "[", 
          RowBox[{"k", ",", "ve", ",", 
           RowBox[{"pq", "[", 
            RowBox[{"k", ",", "ve"}], "]"}], ",", 
           RowBox[{"ve", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", ".3", ",", ".01"}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ne", "=", 
      RowBox[{"Nearest", "[", 
       RowBox[{"outcome", ",", 
        RowBox[{"ve", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{"outcome", ",", 
           RowBox[{"ne", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/", "100"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6650489517603807`*^9, 3.665048953229116*^9}, 
   3.665049204135254*^9, {3.665141774291423*^9, 3.665141780103979*^9}, {
   3.665142250911208*^9, 3.6651422604112854`*^9}, {3.665149276533889*^9, 
   3.665149295694419*^9}},ExpressionUUID->"cc1cefd5-50ed-4207-b09c-\
68f64189c086"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mbest", "[", "ve_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"outcome", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"co", "[", 
          RowBox[{"k", ",", "ve", ",", 
           RowBox[{"pq", "[", 
            RowBox[{"k", ",", "ve"}], "]"}], ",", 
           RowBox[{"ve", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", ".3", ",", ".01"}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ne", "=", 
      RowBox[{"Max", "[", "outcome", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"outcome", ",", "ne"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "100"}], "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.665142240286106*^9, 3.6651422622081966`*^9}, {
   3.6651423378579206`*^9, 3.6651423422329807`*^9}, {3.6651423851927185`*^9, 
   3.6651423866614823`*^9}, {3.6651426391210318`*^9, 3.665142641636685*^9}, {
   3.665142679972001*^9, 3.6651428290847178`*^9}, {3.665142871309951*^9, 
   3.665142955632616*^9}, {3.6651448673246965`*^9, 3.665144909858817*^9}, {
   3.6651492718565607`*^9, 3.665149297838957*^9}, {3.665219970048627*^9, 
   3.6652199706423326`*^9}, 3.66522008558842*^9, {3.6652201174325304`*^9, 
   3.665220118041911*^9}},ExpressionUUID->"abc15add-2487-4443-9af9-\
285705113a7c"],

Cell["\<\
We now just have to make a loop over countries to compute the vector of \
lambdas\
\>", "Text",
 CellChangeTimes->{{3.6573776447403507`*^9, 3.6573776607288923`*^9}, 
   3.6573777649867296`*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"f756ebae-355a-48b6-bc4e-f806248b992b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Quartiles", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"best", "[", 
         RowBox[{"tab0", "[", 
          RowBox[{"[", "m", "]"}], "]"}], " ", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "nd"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.657376334728767*^9, 3.6573763605570974`*^9}, {
   3.657376474184536*^9, 3.6573765028083067`*^9}, {3.659861754341485*^9, 
   3.6598617552477474`*^9}, {3.6598632785908237`*^9, 
   3.6598632802409935`*^9}, {3.6598640061555405`*^9, 3.659864006968049*^9}, 
   3.6621002603921957`*^9, {3.6621022589240417`*^9, 3.662102259752181*^9}, {
   3.662102381383065*^9, 3.6621023948675823`*^9}, {3.6621033023835506`*^9, 
   3.662103304086651*^9}, {3.6621033483528013`*^9, 3.6621033510090714`*^9}, {
   3.665142991403141*^9, 3.6651429917726874`*^9}, {3.665147728092854*^9, 
   3.6651477406387105`*^9}, {3.665147775194245*^9, 3.6651478317112665`*^9}, {
   3.6651491936992702`*^9, 3.665149207869203*^9}, 3.665149241899715*^9, 
   3.6651493018387637`*^9, 3.665149572450368*^9, {3.665150981118923*^9, 
   3.6651509860073633`*^9}},ExpressionUUID->"f4e713f1-ac71-4619-a319-\
ca07d0580390"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665149209157121*^9, 3.6651493115457516`*^9, 
  3.665149590151887*^9, 3.6652185937435346`*^9, 3.6652356165352516`*^9, 
  3.6652358801089077`*^9},ExpressionUUID->"0eef8473-4768-4da3-b632-\
62d336c9bfc7"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665149209157121*^9, 3.6651493115457516`*^9, 
  3.665149590151887*^9, 3.6652185937435346`*^9, 3.6652356165352516`*^9, 
  3.665235880642285*^9},ExpressionUUID->"3e52efd6-75b8-4683-826f-\
9e3dc7bd5895"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665149209157121*^9, 3.6651493115457516`*^9, 
  3.665149590151887*^9, 3.6652185937435346`*^9, 3.6652356165352516`*^9, 
  3.6652358809324903`*^9},ExpressionUUID->"3686fd63-e65a-4341-97e0-\
1b3d2c07f128"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665149209157121*^9, 3.6651493115457516`*^9, 
  3.665149590151887*^9, 3.6652185937435346`*^9, 3.6652356165352516`*^9, 
  3.665235880969516*^9},ExpressionUUID->"ef70d778-028c-47a5-97a8-\
e381ff27af7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1575`", ",", "0.1675`", ",", "0.1575`", ",", "0.13999999999999999`", ",",
    "0.16`", ",", "0.15`", ",", "0.1575`", ",", "0.1475`", ",", "0.1075`", 
   ",", "0.14`", ",", "0.13`", ",", "0.175`", ",", "0.1525`", ",", "0.14`", 
   ",", "0.14`", ",", "0.1675`", ",", "0.135`", ",", "0.16`", ",", "0.1775`", 
   ",", "0.165`", ",", "0.08`", ",", "0.175`", ",", "0.057499999999999996`", 
   ",", "0.1075`", ",", "0.09`", ",", "0.10250000000000001`", ",", 
   "0.13999999999999999`", ",", "0.08`", ",", "0.09`", ",", "0.1475`", ",", 
   "0.1`", ",", "0.2075`", ",", "0.11499999999999999`", ",", "0.235`", ",", 
   "0.125`", ",", "0.1475`", ",", "0.17`", ",", "0.1075`"}], "}"}]], "Output",
 CellChangeTimes->{3.665149221888121*^9, 3.665149398786397*^9, 
  3.6651499005723825`*^9, 3.665219003603824*^9, 3.665235838217651*^9, 
  3.6652373896666584`*^9},ExpressionUUID->"f5c14612-a64d-46de-8250-\
7abb04786bc4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rresult", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Quartiles", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"rbest", "[", 
         RowBox[{"tab0", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "nd"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.66504896791676*^9, 3.66504897007306*^9}, {
   3.6651429939940786`*^9, 3.6651429947641487`*^9}, 3.6651477847099733`*^9, {
   3.6651478444913054`*^9, 3.665147849138592*^9}, {3.6651495956517897`*^9, 
   3.6651496027357984`*^9}, {3.665150971663222*^9, 
   3.665150976995006*^9}},ExpressionUUID->"3ffe6097-0a67-42c0-af43-\
0d26675eeb28"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662102398320692*^9, 3.6621030881956596`*^9, 3.662103209630928*^9, {
   3.6621032894497557`*^9, 3.662103314508638*^9}, 3.662103351477784*^9, 
   3.662103848029989*^9, 3.6621040861693935`*^9, 3.6621043127805433`*^9, 
   3.6621044102638693`*^9, 3.6621044854789305`*^9, 3.6621045227940297`*^9, 
   3.6621046471517696`*^9, 3.662104804601918*^9, 3.6621137149209924`*^9, 
   3.662113935982766*^9, 3.6621142349836335`*^9, 3.662114335913596*^9, 
   3.6621144160181065`*^9, 3.6621145271764154`*^9, 3.6621148385059705`*^9, 
   3.662114944890241*^9, 3.6621150546024313`*^9, 3.662115149576868*^9, 
   3.662115339505207*^9, 3.662115526949915*^9, 3.6621156131752853`*^9, 
   3.6621157792535686`*^9, 3.662116000672389*^9, 3.6623527942284117`*^9, 
   3.6623529400258846`*^9, 3.6623530455358257`*^9, 3.6623535527277613`*^9, 
   3.662353894603017*^9, 3.6623540736526613`*^9, 3.6629816577718544`*^9, 
   3.662998886125354*^9, 3.6650490464075766`*^9, 3.665053456734528*^9, 
   3.665143343036644*^9, 3.66514990068346*^9, 
   3.6652190038069386`*^9},ExpressionUUID->"b5dc2f79-4c80-493f-b4d4-\
1dd71c33f1fa"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662102398320692*^9, 3.6621030881956596`*^9, 3.662103209630928*^9, {
   3.6621032894497557`*^9, 3.662103314508638*^9}, 3.662103351477784*^9, 
   3.662103848029989*^9, 3.6621040861693935`*^9, 3.6621043127805433`*^9, 
   3.6621044102638693`*^9, 3.6621044854789305`*^9, 3.6621045227940297`*^9, 
   3.6621046471517696`*^9, 3.662104804601918*^9, 3.6621137149209924`*^9, 
   3.662113935982766*^9, 3.6621142349836335`*^9, 3.662114335913596*^9, 
   3.6621144160181065`*^9, 3.6621145271764154`*^9, 3.6621148385059705`*^9, 
   3.662114944890241*^9, 3.6621150546024313`*^9, 3.662115149576868*^9, 
   3.662115339505207*^9, 3.662115526949915*^9, 3.6621156131752853`*^9, 
   3.6621157792535686`*^9, 3.662116000672389*^9, 3.6623527942284117`*^9, 
   3.6623529400258846`*^9, 3.6623530455358257`*^9, 3.6623535527277613`*^9, 
   3.662353894603017*^9, 3.6623540736526613`*^9, 3.6629816577718544`*^9, 
   3.662998886125354*^9, 3.6650490464075766`*^9, 3.665053456734528*^9, 
   3.665143343036644*^9, 3.66514990068346*^9, 
   3.665219004353818*^9},ExpressionUUID->"e6d18b2e-2316-4132-afdd-\
8cd1f15248f9"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662102398320692*^9, 3.6621030881956596`*^9, 3.662103209630928*^9, {
   3.6621032894497557`*^9, 3.662103314508638*^9}, 3.662103351477784*^9, 
   3.662103848029989*^9, 3.6621040861693935`*^9, 3.6621043127805433`*^9, 
   3.6621044102638693`*^9, 3.6621044854789305`*^9, 3.6621045227940297`*^9, 
   3.6621046471517696`*^9, 3.662104804601918*^9, 3.6621137149209924`*^9, 
   3.662113935982766*^9, 3.6621142349836335`*^9, 3.662114335913596*^9, 
   3.6621144160181065`*^9, 3.6621145271764154`*^9, 3.6621148385059705`*^9, 
   3.662114944890241*^9, 3.6621150546024313`*^9, 3.662115149576868*^9, 
   3.662115339505207*^9, 3.662115526949915*^9, 3.6621156131752853`*^9, 
   3.6621157792535686`*^9, 3.662116000672389*^9, 3.6623527942284117`*^9, 
   3.6623529400258846`*^9, 3.6623530455358257`*^9, 3.6623535527277613`*^9, 
   3.662353894603017*^9, 3.6623540736526613`*^9, 3.6629816577718544`*^9, 
   3.662998886125354*^9, 3.6650490464075766`*^9, 3.665053456734528*^9, 
   3.665143343036644*^9, 3.66514990068346*^9, 
   3.665219004650696*^9},ExpressionUUID->"23f5b7e1-3ea8-405c-a1eb-\
b807e206f146"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662102398320692*^9, 3.6621030881956596`*^9, 3.662103209630928*^9, {
   3.6621032894497557`*^9, 3.662103314508638*^9}, 3.662103351477784*^9, 
   3.662103848029989*^9, 3.6621040861693935`*^9, 3.6621043127805433`*^9, 
   3.6621044102638693`*^9, 3.6621044854789305`*^9, 3.6621045227940297`*^9, 
   3.6621046471517696`*^9, 3.662104804601918*^9, 3.6621137149209924`*^9, 
   3.662113935982766*^9, 3.6621142349836335`*^9, 3.662114335913596*^9, 
   3.6621144160181065`*^9, 3.6621145271764154`*^9, 3.6621148385059705`*^9, 
   3.662114944890241*^9, 3.6621150546024313`*^9, 3.662115149576868*^9, 
   3.662115339505207*^9, 3.662115526949915*^9, 3.6621156131752853`*^9, 
   3.6621157792535686`*^9, 3.662116000672389*^9, 3.6623527942284117`*^9, 
   3.6623529400258846`*^9, 3.6623530455358257`*^9, 3.6623535527277613`*^9, 
   3.662353894603017*^9, 3.6623540736526613`*^9, 3.6629816577718544`*^9, 
   3.662998886125354*^9, 3.6650490464075766`*^9, 3.665053456734528*^9, 
   3.665143343036644*^9, 3.66514990068346*^9, 
   3.6652190046819544`*^9},ExpressionUUID->"7f033ab6-2cad-4683-9c9a-\
b0fc79f9a21a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1675`", ",", "0.1675`", ",", "0.1575`", ",", "0.14`", ",", "0.16`", ",", 
   "0.155`", ",", "0.1625`", ",", "0.1475`", ",", "0.105`", ",", "0.1375`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.662102378976734*^9, 3.66210240326388*^9}, 
   3.6621030957894897`*^9, 3.6621032151778593`*^9, {3.662103295918561*^9, 
   3.662103319289939*^9}, 3.6621034098464785`*^9, 3.6621039019009714`*^9, 
   3.6621041255448265`*^9, 3.66210436876667*^9, 3.66210446578052*^9, 
   3.6621045138987255`*^9, 3.662104578962408*^9, 3.6621047024510593`*^9, 
   3.6621048606965075`*^9, 3.662113768334962*^9, 3.6621139895927753`*^9, 
   3.662114292473212*^9, 3.662114388432294*^9, 3.662114473593442*^9, 
   3.662114593397833*^9, 3.66211490749907*^9, 3.6621150112589593`*^9, 
   3.66211512124995*^9, 3.662115215464017*^9, 3.6621154070417147`*^9, 
   3.6621155847557964`*^9, 3.6621156797223587`*^9, 3.662115843025176*^9, 
   3.662116067690092*^9, 3.6623528557080803`*^9, 3.6623530029107857`*^9, 
   3.662353108104145*^9, 3.6623536145933275`*^9, 3.662353955421233*^9, 
   3.6623590658364286`*^9, 3.6629858142748127`*^9, 3.6630029141416693`*^9, 
   3.6650491090075445`*^9, 3.665057664326541*^9, 3.6651436497968416`*^9, 
   3.6651502282549953`*^9, 
   3.6652194307848363`*^9},ExpressionUUID->"b34766cd-5073-4106-af47-\
0548e0c7a095"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mresult", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Quartiles", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"mbest", "[", 
          RowBox[{"tab0", "[", 
           RowBox[{"[", "m", "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "1", ",", "nd"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.665142998993428*^9, 3.665143008384139*^9}, {
  3.665144258690442*^9, 3.6651442846570187`*^9}, {3.665147867685711*^9, 
  3.665147874669665*^9}, {3.6651495978763685`*^9, 3.665149606102167*^9}, {
  3.6651509412957582`*^9, 
  3.665150946139183*^9}},ExpressionUUID->"73f595cd-7a0f-42f7-8d58-\
3e1bea6c4112"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665143649928935*^9, 3.6651442861910734`*^9, 
  3.665144916241331*^9, 3.6651456418695335`*^9, 3.6651502284010983`*^9, 
  3.6652194309249353`*^9, 3.6652199768923917`*^9, 3.6652201420221167`*^9, 
  3.665237389837018*^9, 3.6652414670317764`*^9, 
  3.6652564239810405`*^9},ExpressionUUID->"ef4382ee-7361-4b4b-9275-\
312eb69143f7"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665143649928935*^9, 3.6651442861910734`*^9, 
  3.665144916241331*^9, 3.6651456418695335`*^9, 3.6651502284010983`*^9, 
  3.6652194309249353`*^9, 3.6652199768923917`*^9, 3.6652201420221167`*^9, 
  3.665237389837018*^9, 3.6652414670317764`*^9, 
  3.6652564404812155`*^9},ExpressionUUID->"29169a4d-5cb8-472f-9d9c-\
30b0590a2267"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665143649928935*^9, 3.6651442861910734`*^9, 
  3.665144916241331*^9, 3.6651456418695335`*^9, 3.6651502284010983`*^9, 
  3.6652194309249353`*^9, 3.6652199768923917`*^9, 3.6652201420221167`*^9, 
  3.665237389837018*^9, 3.6652414670317764`*^9, 
  3.665256448918804*^9},ExpressionUUID->"ff918010-8805-46a1-806d-\
08d15b4d4a05"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"FindRoot\\\", \\\"::\\\", \\\"lstol\\\
\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665143649928935*^9, 3.6651442861910734`*^9, 
  3.665144916241331*^9, 3.6651456418695335`*^9, 3.6651502284010983`*^9, 
  3.6652194309249353`*^9, 3.6652199768923917`*^9, 3.6652201420221167`*^9, 
  3.665237389837018*^9, 3.6652414670317764`*^9, 
  3.665256448950036*^9},ExpressionUUID->"e7f1af4c-aec0-4687-be59-\
1bfc4bbe9cfa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.125`", ",", "0.0975`", ",", "0.09`", ",", "0.0975`", ",", "0.15`", ",", 
   "0.1175`", ",", "0.135`", ",", "0.12`", ",", "0.09`", ",", "0.11`", ",", 
   "0.1075`", ",", "0.0875`", ",", "0.12`", ",", "0.1275`", ",", "0.1375`", 
   ",", "0.1`", ",", "0.1`", ",", "0.1375`", ",", "0.16`", ",", "0.1175`", 
   ",", "0.057499999999999996`", ",", "0.11`", ",", "0.06`", ",", "0.1`", ",",
    "0.11`", ",", "0.08`", ",", "0.07`", ",", "0.1`", ",", "0.0775`", ",", 
   "0.11499999999999999`", ",", "0.0875`", ",", "0.225`", ",", "0.0875`", ",",
    "0.1625`", ",", "0.0975`", ",", "0.1375`", ",", "0.14`", ",", "0.07`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6651439801073723`*^9, 3.665144374103258*^9, 
  3.665145213768198*^9, 3.6651459871952143`*^9, 3.6651505325523076`*^9, 
  3.665219884674424*^9, 3.6652200140671844`*^9, 3.6652205610815654`*^9, 
  3.665239649316794*^9, 3.6652519510283604`*^9, 
  3.665309059219202*^9},ExpressionUUID->"6c332dfc-fcc9-4b5d-85ee-\
f31cefe47698"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"output", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mresult", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"p", "[", "1", "]"}], ",", 
        RowBox[{"p", "[", "2", "]"}], ",", 
        RowBox[{"p", "[", "3", "]"}], ",", 
        RowBox[{"p", "[", "4", "]"}], ",", 
        RowBox[{"p", "[", "5", "]"}], ",", 
        RowBox[{"p", "[", "6", "]"}], ",", 
        RowBox[{"p", "[", "7", "]"}], ",", 
        RowBox[{"p", "[", "8", "]"}], ",", 
        RowBox[{"p", "[", "9", "]"}], ",", 
        RowBox[{"p", "[", "10", "]"}], ",", 
        RowBox[{"p", "[", "11", "]"}], ",", 
        RowBox[{"p", "[", "12", "]"}], ",", 
        RowBox[{"p", "[", "13", "]"}], ",", 
        RowBox[{"p", "[", "14", "]"}], ",", 
        RowBox[{"p", "[", "15", "]"}], ",", 
        RowBox[{"p", "[", "16", "]"}], ",", 
        RowBox[{"p", "[", "17", "]"}], ",", 
        RowBox[{"p", "[", "18", "]"}], ",", 
        RowBox[{"p", "[", "19", "]"}], ",", 
        RowBox[{"q", "[", "1", "]"}], ",", 
        RowBox[{"q", "[", "2", "]"}], ",", 
        RowBox[{"q", "[", "3", "]"}], ",", 
        RowBox[{"q", "[", "4", "]"}], ",", 
        RowBox[{"q", "[", "5", "]"}], ",", 
        RowBox[{"q", "[", "6", "]"}], ",", 
        RowBox[{"q", "[", "7", "]"}], ",", 
        RowBox[{"q", "[", "8", "]"}], ",", 
        RowBox[{"q", "[", "9", "]"}], ",", 
        RowBox[{"q", "[", "10", "]"}], ",", 
        RowBox[{"q", "[", "11", "]"}], ",", 
        RowBox[{"q", "[", "12", "]"}], ",", 
        RowBox[{"q", "[", "13", "]"}], ",", 
        RowBox[{"q", "[", "14", "]"}], ",", 
        RowBox[{"q", "[", "15", "]"}], ",", 
        RowBox[{"q", "[", "16", "]"}], ",", 
        RowBox[{"q", "[", "17", "]"}], ",", 
        RowBox[{"q", "[", "18", "]"}], ",", 
        RowBox[{"q", "[", "19", "]"}]}], "}"}], "/.", 
      RowBox[{"pq", "[", 
       RowBox[{
        RowBox[{"mresult", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"tab0", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "nd"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<assort.dat\>\"", ",", "output", ",", "\"\<Table\>\""}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6598633517456136`*^9, 3.6598633993616114`*^9}, {
   3.6598634471226964`*^9, 3.6598634932053304`*^9}, {3.6598635679506893`*^9, 
   3.6598636612155*^9}, {3.6598637027221317`*^9, 3.6598637163788033`*^9}, {
   3.659863821430749*^9, 3.65986382343077*^9}, {3.6598640086711636`*^9, 
   3.659864009577427*^9}, 3.6598640782330494`*^9, 3.65987809819354*^9, {
   3.662359657902378*^9, 3.662359659834258*^9}, {3.6651509970001264`*^9, 
   3.6651509989384985`*^9}},ExpressionUUID->"f78240dc-6630-4a0b-be99-\
e43e8ec20cbe"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], ":", 
  " ", "\<\"The line search decreased the step size to within tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\)\[NoBreak] digits of \
working precision to meet these tolerances. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.665309059927703*^9},ExpressionUUID->"5254e7e3-998d-4267-8984-\
183df68a2a78"],

Cell[BoxData["\<\"assort.dat\"\>"], "Output",
 CellChangeTimes->{
  3.6598634937637305`*^9, 3.659863656540331*^9, {3.6598637096550474`*^9, 
   3.6598637180459943`*^9}, 3.6598638244151206`*^9, 3.6598675471796737`*^9, 
   3.6598697560479317`*^9, 3.6617894454990163`*^9, 3.6623591059356303`*^9, 
   3.6629858152334824`*^9, 3.6630029150353026`*^9, 3.665219890120701*^9, 
   3.6652519519033585`*^9, 
   3.6653090602729497`*^9},ExpressionUUID->"3ec3a0ae-ee9a-42a1-a428-\
20fbf843e5e8"]
}, Open  ]],

Cell["\<\
Plot of the resulting outcome for a women have ef=6, ef=13, ef=0, ef=18 / \
global lambda\
\>", "Text",
 CellChangeTimes->{{3.6573776447403507`*^9, 3.6573776607288923`*^9}, 
   3.6573777649867296`*^9, {3.6573958319150248`*^9, 3.657395851634036*^9}, {
   3.657626843058033*^9, 3.6576268489571967`*^9}, {3.659863235980982*^9, 
   3.659863237502067*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"ac595ec7-5487-4771-8604-4eaf6b82f7b9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lambda1", "=", ".1375"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vec", "=", 
   RowBox[{"tab0", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6621001279645915`*^9, 3.6621001406834764`*^9}, {
  3.6621004952042103`*^9, 3.6621004959229684`*^9}, {3.662100837365294*^9, 
  3.6621008376495085`*^9}, {3.6623591105402155`*^9, 3.6623591114465227`*^9}, {
  3.665141892179544*^9, 3.6651418928201604`*^9}, {3.6652552069354753`*^9, 
  3.6652552078320875`*^9}},ExpressionUUID->"6966e0f8-efab-4ff8-a08e-\
2c4572637fc0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "j_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"6", "+", "1"}], "]"}], " ", 
     RowBox[{"q", "[", 
      RowBox[{"j", "+", "1"}], "]"}], " ", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"j", "-", "6"}], ",", "lambda1"}], "]"}], " ", 
     RowBox[{"vec", "[", 
      RowBox[{"[", 
       RowBox[{"22", "+", "j"}], "]"}], "]"}]}], "/.", 
    RowBox[{"pq", "[", 
     RowBox[{"lambda1", ",", "vec"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"g", "[", "k", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"vec", "[", 
        RowBox[{"[", 
         RowBox[{"22", "+", "k"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tb1", ",", "tb2"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.657395596322671*^9, 3.65739582121624*^9}, 
   3.6598618782136073`*^9, {3.659862574508715*^9, 3.6598626235994043`*^9}, 
   3.659877308642517*^9, {3.6620998905260735`*^9, 3.662099898057453*^9}, {
   3.6621000955135255`*^9, 3.6621001118574505`*^9}, {3.662100144574168*^9, 
   3.6621001494960966`*^9}, 3.6621008349766307`*^9, {3.662102202462375*^9, 
   3.6621022046655235`*^9}, 
   3.662115174070896*^9},ExpressionUUID->"a31015be-2912-450c-81b6-\
c1b88bd87cde"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQMTt5nU73hUZQ/hfbB/tSVJoM1wH5TP4PC8Vm9R
1MoJUD6HwzEDB5asoGVQvoADt3/bH+Y9W6B8EYfMAy8/nww7BuVLOBzcF3jk
Hs9mKF/GIdlmzuYvT45A+QoOB3f8u7A2dhOUr+Tgpj1HtcloBZSv4iBy0ETN
4AvMfDUHHr9d6vs4p0D5Gg67pss+YXJdDOVrOXidZvNcm70UytdxkJvZnSRi
WAjl6zm8zN4uts22AMo3cLjqtd+s/XMjlG/ooHYk6k7RqQYo38hhd/gxy00X
C+0BsfFSSw==
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQObkpUF1r9ut4fwPtibxu3y5GE6DuUzOJxfsLC+
qXsqlM/hsEkvbzHjnqVQvoCD84RmobRb66B8EQfdiovhE9IOQPkSDrNem1wK
qlwN5cs4fF3I/Sr62R4oX8Fh945etg9iK6B8JYeNP3eYhfQshvJVHO5Nbm+N
urwFyldz6EiOvePGPAPK13D45qBtkFIKM1/LwUlN0pK7ehOUr+PwxzRysdyi
RihfzyFPHOSiJijfwCFubrLDt6rpUL6hg/iV7WdeboKZb+SwZfLBwE+veuwB
ZlRTAg==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 18.}, {0, 0.17975}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6573956745876245`*^9, 3.657395681675704*^9}, {
   3.6573957126071234`*^9, 3.6573957429388113`*^9}, 3.6573957997171288`*^9, 
   3.657395888120225*^9, {3.6576267681996694`*^9, 3.6576267750745225`*^9}, {
   3.6598626148492937`*^9, 3.6598626254744115`*^9}, 3.65986975662608*^9, 
   3.6598773101268673`*^9, 3.6617894461414847`*^9, {3.662100089872788*^9, 
   3.662100112513672*^9}, 3.662100287314356*^9, 3.6621004994073524`*^9, 
   3.662102205759231*^9, 3.662359114259007*^9, 3.6629858158089027`*^9, 
   3.662985913038762*^9, 3.6630029156697717`*^9, {3.665141888507617*^9, 
   3.665141895195196*^9}, 3.6652198907021284`*^9, 
   3.665255210372854*^9},ExpressionUUID->"40ba4ad7-db97-4d2d-8651-\
2d28ef2a5365"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "j_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"13", "+", "1"}], "]"}], " ", 
     RowBox[{"q", "[", 
      RowBox[{"j", "+", "1"}], "]"}], " ", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"j", "-", "13"}], ",", "lambda1"}], "]"}], " ", 
     RowBox[{"vec", "[", 
      RowBox[{"[", 
       RowBox[{"22", "+", "j"}], "]"}], "]"}]}], "/.", 
    RowBox[{"pq", "[", 
     RowBox[{"lambda1", ",", "vec"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"g", "[", "k", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"vec", "[", 
        RowBox[{"[", 
         RowBox[{"22", "+", "k"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tb1", ",", "tb2"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6576267907625933`*^9, 3.6576268096469297`*^9}, {
   3.6598626500840745`*^9, 3.6598626752980146`*^9}, {3.662099908323188*^9, 
   3.662099911620099*^9}, {3.662100152355502*^9, 3.662100156058667*^9}, 
   3.6621022142281265`*^9},ExpressionUUID->"6ca6512c-b965-41e4-8775-\
aa9039974674"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQOialv5VcyC7SG8D/aV+3Y52EyeCuUzOMhrczTv
Pp8O5XM4eC9dMXH+s3ooX8Dh1ObDzFcW9kL5Ig4zvr5a9Zp5KZQv4SBQ5i4g
OWM6lC/j4LaL+9xdjo1QvoJDBdup9Ipti6F8JYel1xUEGJuWQfkqDinNnWHa
Tw5A+WoO/vyss/z/r4byNRwOz2P15d15EMrXcng6e/ubj+9PQvk6DhrNlyWf
pM+G8vUcQmQvXHrPtRDKN3C4JSDoE3ttE5Rv6CDLcfT3vHkw9xk52O/+febO
pkX2AIxXUcg=
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQObkpUF1r9ut4fwPtibxu3y5GE6DuUzOJxfsLC+
qXsqlM/hsEkvbzHjnqVQvoCD84RmobRb66B8EQfdiovhE9IOQPkSDrNem1wK
qlwN5cs4fF3I/Sr62R4oX8Fh945etg9iK6B8JYeNP3eYhfQshvJVHO5Nbm+N
urwFyldz6EiOvePGPAPK13D45qBtkFIKM1/LwUlN0pK7ehOUr+PwxzRysdyi
RihfzyFPHOSiJijfwCFubrLDt6rpUL6hg/iV7WdeboKZb+SwZfLBwE+veuwB
ZlRTAg==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 18.}, {0, 0.2026350408407033}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6576268014291162`*^9, 3.6576268102563477`*^9}, 
   3.6598626786573896`*^9, 3.6598697570010805`*^9, 3.6598773133300285`*^9, 
   3.6617894466838555`*^9, 3.6621022155562267`*^9, 3.6623591164192095`*^9, 
   3.662985816396308*^9, 3.6630029162451835`*^9, 3.6651419019880395`*^9, 
   3.6652198913031993`*^9, 
   3.665255224121479*^9},ExpressionUUID->"3a2643ed-7086-495c-9501-\
15d1a0e030f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "j_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], " ", 
     RowBox[{"q", "[", 
      RowBox[{"j", "+", "1"}], "]"}], " ", 
     RowBox[{"f", "[", 
      RowBox[{"j", ",", "lambda1"}], "]"}], " ", 
     RowBox[{"vec", "[", 
      RowBox[{"[", 
       RowBox[{"22", "+", "j"}], "]"}], "]"}]}], "/.", 
    RowBox[{"pq", "[", 
     RowBox[{"lambda1", ",", "vec"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"g", "[", "k", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"vec", "[", 
        RowBox[{"[", 
         RowBox[{"22", "+", "k"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tb1", ",", "tb2"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6576268214927936`*^9, 3.6576268251373672`*^9}, {
   3.659862682579321*^9, 3.659862716634104*^9}, 3.659862748108235*^9, {
   3.662099920088941*^9, 3.6620999233546047`*^9}, {3.6621001588555717`*^9, 
   3.6621001630431175`*^9}, 
   3.662102219103178*^9},ExpressionUUID->"bb6d4fac-fb5c-49f3-b372-\
4080aad2e01d"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQOqnH3bDSXm20N4H+w1jhkz27XdgvIZHFJt9D57
2CyD8jkcuk93Vz3S3wjlCzhICTQ9/ZK9CcoXcShRm5+xWG0flC/hoP1i9q7d
7YuhfBkHV5vcFDfXDVC+gsNljvPHP+6cCuUrOTT68658Nb8HyldxWLvnk+Wa
kzOgfDWHzrLD+0O2lEP5Gg45GVvbZp1ug/K1HH7tr3NgC++E8nUc9DYzGkaE
hUD5eg5bX8uWFJkFQ/kGDrUPu7jjbVKhfEMHq8r+9Pd3kqF8I4d8t+LoSJFQ
ewDoPU5l
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQObkpUF1r9ut4fwPtibxu3y5GE6DuUzOJxfsLC+
qXsqlM/hsEkvbzHjnqVQvoCD84RmobRb66B8EQfdiovhE9IOQPkSDrNem1wK
qlwN5cs4fF3I/Sr62R4oX8Fh945etg9iK6B8JYeNP3eYhfQshvJVHO5Nbm+N
urwFyldz6EiOvePGPAPK13D45qBtkFIKM1/LwUlN0pK7ehOUr+PwxzRysdyi
RihfzyFPHOSiJijfwCFubrLDt6rpUL6hg/iV7WdeboKZb+SwZfLBwE+veuwB
ZlRTAg==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 18.}, {0, 0.4144434958717249}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6576268263001738`*^9, 3.659862720092225*^9, 
  3.659869757376087*^9, 3.659877316251931*^9, 3.6617894470741315`*^9, 
  3.662102219962508*^9, 3.6623591181223383`*^9, 3.6629858168576527`*^9, 
  3.6630029166674805`*^9, 3.665141913672142*^9, 3.6652198921046333`*^9, 
  3.665255230293432*^9},ExpressionUUID->"fe570c6f-f532-49fc-b383-\
6f88e9d23f72"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "j_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"18", "+", "1"}], "]"}], " ", 
     RowBox[{"q", "[", 
      RowBox[{"j", "+", "1"}], "]"}], " ", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"j", "-", "18"}], ",", "lambda1"}], "]"}], " ", 
     RowBox[{"vec", "[", 
      RowBox[{"[", 
       RowBox[{"22", "+", "j"}], "]"}], "]"}]}], "/.", 
    RowBox[{"pq", "[", 
     RowBox[{"lambda1", ",", "vec"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"g", "[", "k", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tb2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"vec", "[", 
        RowBox[{"[", 
         RowBox[{"22", "+", "k"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "18"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tb1", ",", "tb2"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6576268214927936`*^9, 3.6576268251373672`*^9}, {
  3.657628758791173*^9, 3.6576287630511723`*^9}, {3.6598627659522347`*^9, 
  3.659862774999183*^9}, {3.662099928120237*^9, 3.662099930854679*^9}, {
  3.6621001662931004`*^9, 3.6621001706681986`*^9}, {3.6621022229861636`*^9, 
  3.66210222700183*^9}},ExpressionUUID->"58256b4f-622c-46a7-ad0b-\
42d21460a373"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQP/FO+WfuZztIfwPtivdtovZa3RDOUzOOz9Hsk3
USUUyudw2GNw+l1scA6UL+CgYfrn0Er/KihfxEGp567/rxWToHwJhwnP2s9o
fW6B8mUcqmwvtTk7zIPyFRy431t8ftowEcpXcvi/KajG9s9kKF/FIZjdL0ji
/1ooX83h5CPRBzx3ZkD5Gg6h2XNY927fAuVrOWhJ/dMs+noYytdxeN0k4TXr
8GwoX8/hyPrHcWy7l0H5Bg5aTBvffD56FMo3dPjvl/L2yflTUL6Rg/e7X0o/
dx2yBwBwr1bx
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQObkpUF1r9ut4fwPtibxu3y5GE6DuUzOJxfsLC+
qXsqlM/hsEkvbzHjnqVQvoCD84RmobRb66B8EQfdiovhE9IOQPkSDrNem1wK
qlwN5cs4fF3I/Sr62R4oX8Fh945etg9iK6B8JYeNP3eYhfQshvJVHO5Nbm+N
urwFyldz6EiOvePGPAPK13D45qBtkFIKM1/LwUlN0pK7ehOUr+PwxzRysdyi
RihfzyFPHOSiJijfwCFubrLDt6rpUL6hg/iV7WdeboKZb+SwZfLBwE+veuwB
ZlRTAg==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 18.}, {0, 0.2094694289340779}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6576287650445757`*^9, 3.6598627774395885`*^9, 3.6598697578917093`*^9, 
   3.659877318408205*^9, 3.661789447461407*^9, {3.6621022240798845`*^9, 
   3.6621022280486794`*^9}, 3.662359120012979*^9, 3.6629858173259816`*^9, 
   3.6630029170867624`*^9, 3.6651419194171324`*^9, 3.6652198925489354`*^9, 
   3.665255233137209*^9},ExpressionUUID->"a87216e5-31a8-40c7-bb74-\
17aadfc74ca9"]
}, Open  ]]
},
WindowSize->{3808, 1937},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.8}},
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 6513, 158, 936, "Input",ExpressionUUID->"27519406-215c-4ab1-ab13-f3a12ddf6376"],
Cell[7074, 180, 396, 9, 234, "Text",ExpressionUUID->"695de352-d3dc-42e2-b833-6607390127ca"],
Cell[7473, 191, 730, 20, 71, "Input",ExpressionUUID->"c23f70e5-31fa-4c1f-ac0c-fd204b44de1c"],
Cell[8206, 213, 1115, 24, 168, "Input",ExpressionUUID->"9fe64fb9-2759-4216-a8d1-e76e5405e485"],
Cell[9324, 239, 266, 6, 85, "Text",ExpressionUUID->"24efd72f-fec2-4275-8baf-be2da8329aa5"],
Cell[9593, 247, 406, 8, 125, "Text",ExpressionUUID->"a4c4084c-c93b-4605-98e2-599b0e235a07"],
Cell[10002, 257, 6276, 145, 360, "Input",ExpressionUUID->"a018c05a-20ab-48ac-ae88-db7c79f878bd"],
Cell[CellGroupData[{
Cell[16303, 406, 319, 8, 71, "Input",ExpressionUUID->"706c8139-2275-44db-9f08-a599218e3411"],
Cell[16625, 416, 3928, 88, 226, "Output",ExpressionUUID->"473d725a-b17e-4fc8-9249-0ef2b182e52b"]
}, Open  ]],
Cell[20568, 507, 375, 6, 125, "Text",ExpressionUUID->"ec6d92b0-e321-462b-a40c-88b25bfb80fa"],
Cell[20946, 515, 5072, 139, 408, "Input",ExpressionUUID->"2095fa5b-feb7-40f7-8fe4-4982ae78869e"],
Cell[CellGroupData[{
Cell[26043, 658, 857, 19, 71, "Input",ExpressionUUID->"4fe3b955-64df-4b73-85de-a6b4ae7c3488"],
Cell[26903, 679, 2809, 46, 1742, "Output",ExpressionUUID->"f1e3b45d-3524-436a-b851-5e5b63dc6097"]
}, Open  ]],
Cell[29727, 728, 775, 16, 452, "Text",ExpressionUUID->"e63d43c3-377b-4dd1-8713-ce4636166c18"],
Cell[30505, 746, 10488, 227, 792, "Input",ExpressionUUID->"f893e209-70cc-41c2-b314-e46fb9081f75"],
Cell[40996, 975, 379, 7, 125, "Text",ExpressionUUID->"cb17ea4d-220f-475a-b70d-86a923f606ba"],
Cell[CellGroupData[{
Cell[41400, 986, 1044, 26, 120, "Input",ExpressionUUID->"dfea53b1-0cdf-40d8-b24f-24a630f53943"],
Cell[42447, 1014, 924, 16, 58, "Message",ExpressionUUID->"0cda0d7d-4cec-4d82-a75f-ef35c52c3f38"],
Cell[43374, 1032, 922, 16, 58, "Message",ExpressionUUID->"fc81178e-1fa9-4505-9f19-4b4962e7f927"],
Cell[44299, 1050, 924, 16, 58, "Message",ExpressionUUID->"0022e20c-79ca-41b6-8372-5316f79a9040"],
Cell[45226, 1068, 777, 15, 58, "Message",ExpressionUUID->"a309af74-56b0-4778-835b-dbbaa1922a34"],
Cell[46006, 1085, 1952, 33, 130, "Output",ExpressionUUID->"643b25a0-8493-43e5-a5f8-03ce66c64a85"],
Cell[47961, 1120, 2293, 48, 589, "Output",ExpressionUUID->"b549b084-27ce-4862-b15a-4a68415f12cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50291, 1173, 958, 26, 120, "Input",ExpressionUUID->"ffc38958-b8c7-4a08-af23-58cb2be80500"],
Cell[51252, 1201, 906, 16, 58, "Message",ExpressionUUID->"c95026a7-f2de-4e81-81cb-b88816a5279c"],
Cell[52161, 1219, 904, 16, 58, "Message",ExpressionUUID->"b18d0c2b-c9cb-4188-9332-620629eed59a"],
Cell[53068, 1237, 904, 16, 58, "Message",ExpressionUUID->"e93c74ef-4396-4db5-8e87-361c2a3f37bc"],
Cell[53975, 1255, 759, 15, 58, "Message",ExpressionUUID->"7513bee6-66f2-4bba-b87d-e0a374c09ca2"],
Cell[54737, 1272, 1307, 24, 130, "Output",ExpressionUUID->"07afd5c3-5980-4db6-b77f-b1efde94d122"],
Cell[56047, 1298, 1639, 39, 609, "Output",ExpressionUUID->"c9a3668e-49eb-4a7a-a67f-d58304234b6a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57723, 1342, 933, 25, 120, "Input",ExpressionUUID->"6eed27f0-cd9b-42c9-9779-7270fed2e62a"],
Cell[58659, 1369, 946, 16, 58, "Message",ExpressionUUID->"1e3b9981-42ff-4add-b13b-d4fce01b86cb"],
Cell[59608, 1387, 946, 16, 58, "Message",ExpressionUUID->"e6114e25-8160-4894-b7ad-7f7ea56b11f7"],
Cell[60557, 1405, 948, 16, 58, "Message",ExpressionUUID->"ccd42afa-743a-4354-a1e0-001241ee6900"],
Cell[61508, 1423, 801, 15, 58, "Message",ExpressionUUID->"0302fecb-e152-4b34-8d2f-36cb5620fdf5"],
Cell[62312, 1440, 1235, 20, 130, "Output",ExpressionUUID->"af9e9ba7-1ffd-4ac3-a241-ee1fd2c8aed1"],
Cell[63550, 1462, 1633, 37, 622, "Output",ExpressionUUID->"393ebc7e-b902-4f7b-b5bc-a4b400bad3b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65220, 1504, 875, 24, 120, "Input",ExpressionUUID->"9cb02491-60fa-4ee7-90cd-c74850ad77e3"],
Cell[66098, 1530, 1017, 17, 58, "Message",ExpressionUUID->"9d9f631b-b506-44ff-b9ec-a8541c356ce5"],
Cell[67118, 1549, 1015, 17, 58, "Message",ExpressionUUID->"ef0e03ac-c187-4e66-8885-ba900e015172"],
Cell[68136, 1568, 1017, 17, 58, "Message",ExpressionUUID->"f4724528-08e6-4b7c-beb2-8a6ff1902329"],
Cell[69156, 1587, 870, 16, 58, "Message",ExpressionUUID->"615bca55-6125-4d02-8e01-b1c737bdb403"],
Cell[70029, 1605, 1343, 24, 130, "Output",ExpressionUUID->"05b7243a-a8df-4163-8904-02bc919327ef"],
Cell[71375, 1631, 1697, 38, 609, "Output",ExpressionUUID->"2f43b5e0-070f-468b-b0aa-faad7de7625e"]
}, Open  ]],
Cell[73087, 1672, 546, 11, 234, "Text",ExpressionUUID->"e3bb8231-0dc9-4ac7-843f-992a94f3a0e2"],
Cell[73636, 1685, 1841, 45, 216, "Input",ExpressionUUID->"742636b5-6e28-4648-9bb6-6eca412ff52d"],
Cell[75480, 1732, 1529, 41, 216, "Input",ExpressionUUID->"cc1cefd5-50ed-4207-b09c-68f64189c086"],
Cell[77012, 1775, 1727, 40, 216, "Input",ExpressionUUID->"abc15add-2487-4443-9af9-285705113a7c"],
Cell[78742, 1817, 299, 7, 125, "Text",ExpressionUUID->"f756ebae-355a-48b6-bc4e-f806248b992b"],
Cell[CellGroupData[{
Cell[79066, 1828, 1400, 28, 71, "Input",ExpressionUUID->"f4e713f1-ac71-4619-a319-ca07d0580390"],
Cell[80469, 1858, 877, 15, 58, "Message",ExpressionUUID->"0eef8473-4768-4da3-b632-62d336c9bfc7"],
Cell[81349, 1875, 875, 15, 58, "Message",ExpressionUUID->"3e52efd6-75b8-4683-826f-9e3dc7bd5895"],
Cell[82227, 1892, 877, 15, 58, "Message",ExpressionUUID->"3686fd63-e65a-4341-97e0-1b3d2c07f128"],
Cell[83107, 1909, 730, 14, 58, "Message",ExpressionUUID->"ef70d778-028c-47a5-97a8-e381ff27af7f"],
Cell[83840, 1925, 948, 15, 130, "Output",ExpressionUUID->"f5c14612-a64d-46de-8250-7abb04786bc4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84825, 1945, 863, 21, 71, "Input",ExpressionUUID->"3ffe6097-0a67-42c0-af43-0d26675eeb28"],
Cell[85691, 1968, 1763, 28, 58, "Message",ExpressionUUID->"b5dc2f79-4c80-493f-b4d4-1dd71c33f1fa"],
Cell[87457, 1998, 1761, 28, 58, "Message",ExpressionUUID->"e6d18b2e-2316-4132-afdd-8cd1f15248f9"],
Cell[89221, 2028, 1761, 28, 58, "Message",ExpressionUUID->"23f5b7e1-3ea8-405c-a1eb-b807e206f146"],
Cell[90985, 2058, 1618, 27, 58, "Message",ExpressionUUID->"7f033ab6-2cad-4683-9c9a-b0fc79f9a21a"],
Cell[92606, 2087, 1345, 22, 81, "Output",ExpressionUUID->"b34766cd-5073-4106-af47-0548e0c7a095"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93988, 2114, 886, 23, 120, "Input",ExpressionUUID->"73f595cd-7a0f-42f7-8d58-3e1bea6c4112"],
Cell[94877, 2139, 1001, 17, 58, "Message",ExpressionUUID->"ef4382ee-7361-4b4b-9275-312eb69143f7"],
Cell[95881, 2158, 1001, 17, 58, "Message",ExpressionUUID->"29169a4d-5cb8-472f-9d9c-30b0590a2267"],
Cell[96885, 2177, 999, 17, 58, "Message",ExpressionUUID->"ff918010-8805-46a1-806d-08d15b4d4a05"],
Cell[97887, 2196, 854, 16, 58, "Message",ExpressionUUID->"e7f1af4c-aec0-4687-be59-1bfc4bbe9cfa"],
Cell[98744, 2214, 1022, 17, 130, "Output",ExpressionUUID->"6c332dfc-fcc9-4b5d-85ee-f31cefe47698"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99803, 2236, 2915, 67, 264, "Input",ExpressionUUID->"f78240dc-6630-4a0b-be99-e43e8ec20cbe"],
Cell[102721, 2305, 756, 14, 58, "Message",ExpressionUUID->"5254e7e3-998d-4267-8984-183df68a2a78"],
Cell[103480, 2321, 479, 8, 81, "Output",ExpressionUUID->"3ec3a0ae-ee9a-42a1-a428-20fbf843e5e8"]
}, Open  ]],
Cell[103974, 2332, 457, 9, 125, "Text",ExpressionUUID->"ac595ec7-5487-4771-8604-4eaf6b82f7b9"],
Cell[104434, 2343, 591, 12, 120, "Input",ExpressionUUID->"6966e0f8-efab-4ff8-a08e-2c4572637fc0"],
Cell[CellGroupData[{
Cell[105050, 2359, 1812, 52, 216, "Input",ExpressionUUID->"a31015be-2912-450c-81b6-c1b88bd87cde"],
Cell[106865, 2413, 2325, 50, 601, "Output",ExpressionUUID->"40ba4ad7-db97-4d2d-8651-2d28ef2a5365"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109227, 2468, 1689, 50, 216, "Input",ExpressionUUID->"6ca6512c-b965-41e4-8775-aa9039974674"],
Cell[110919, 2520, 2019, 46, 601, "Output",ExpressionUUID->"3a2643ed-7086-495c-9501-15d1a0e030f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112975, 2571, 1658, 49, 216, "Input",ExpressionUUID->"bb6d4fac-fb5c-49f3-b372-4080aad2e01d"],
Cell[114636, 2622, 1973, 45, 609, "Output",ExpressionUUID->"fe570c6f-f532-49fc-b383-6f88e9d23f72"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116646, 2672, 1762, 51, 216, "Input",ExpressionUUID->"58256b4f-622c-46a7-ad0b-42d21460a373"],
Cell[118411, 2725, 2014, 46, 601, "Output",ExpressionUUID->"a87216e5-31a8-40c7-bb74-17aadfc74ca9"]
}, Open  ]]
}
]
*)

